@@ -30,6 +30,7 @@
 #include "e-table-group-leaf.h"
 #include "e-table-item.h"
 #include "gal/util/e-util.h"
+#include "gal/util/e-unicode-i18n.h"
 #include "gal/widgets/e-canvas.h"
 #include "gal/widgets/e-canvas-utils.h"
 #include "gal/widgets/e-unicode.h"
@@ -44,19 +45,19 @@ static GnomeCanvasGroupClass *etgc_parent_class;
 
 /* The arguments we take */
 enum {
-	PROP_0,
-	PROP_HEIGHT,
-	PROP_WIDTH,
-	PROP_MINIMUM_WIDTH,
-	PROP_FROZEN,
-	PROP_TABLE_ALTERNATING_ROW_COLORS,
-	PROP_TABLE_HORIZONTAL_DRAW_GRID,
-	PROP_TABLE_VERTICAL_DRAW_GRID,
-	PROP_TABLE_DRAW_FOCUS,
-	PROP_CURSOR_MODE,
-	PROP_SELECTION_MODEL,
-	PROP_LENGTH_THRESHOLD,
-	PROP_UNIFORM_ROW_HEIGHT
+	ARG_0,
+	ARG_HEIGHT,
+	ARG_WIDTH,
+	ARG_MINIMUM_WIDTH,
+	ARG_FROZEN,
+	ARG_TABLE_ALTERNATING_ROW_COLORS,
+	ARG_TABLE_HORIZONTAL_DRAW_GRID,
+	ARG_TABLE_VERTICAL_DRAW_GRID,
+	ARG_TABLE_DRAW_FOCUS,
+	ARG_CURSOR_MODE,
+	ARG_SELECTION_MODEL,
+	ARG_LENGTH_THRESHOLD,
+	ARG_UNIFORM_ROW_HEIGHT,
 };
 
 typedef struct {
@@ -103,34 +104,33 @@ e_table_group_container_list_free (ETableGroupContainer *etgc)
 }
 
 static void
-etgc_dispose (GObject *object)
+etgc_destroy (GtkObject *object)
 {
 	ETableGroupContainer *etgc = E_TABLE_GROUP_CONTAINER (object);
 
-	if (etgc->children)
-		e_table_group_container_list_free (etgc);
-
 	if (etgc->font)
 		gdk_font_unref (etgc->font);
 	etgc->font = NULL;
 
 	if (etgc->ecol)
-		g_object_unref (etgc->ecol);
+		gtk_object_unref (GTK_OBJECT(etgc->ecol));
 	etgc->ecol = NULL;
 
 	if (etgc->sort_info)
-		g_object_unref (etgc->sort_info);
+		gtk_object_unref (GTK_OBJECT(etgc->sort_info));
 	etgc->sort_info = NULL;
 
 	if (etgc->selection_model)
-		g_object_unref (etgc->selection_model);
+		gtk_object_unref (GTK_OBJECT(etgc->selection_model));
 	etgc->selection_model = NULL;
 
 	if (etgc->rect)
 		gtk_object_destroy (GTK_OBJECT(etgc->rect));
 	etgc->rect = NULL;
 
-	G_OBJECT_CLASS (etgc_parent_class)->dispose (object);
+	e_table_group_container_list_free (etgc);
+
+	GTK_OBJECT_CLASS (etgc_parent_class)->destroy (object);
 }
 
 /** 
@@ -160,9 +160,9 @@ e_table_group_container_construct (GnomeCanvasGroup *parent, ETableGroupContaine
 
 	e_table_group_construct (parent, E_TABLE_GROUP (etgc), full_header, header, model);
 	etgc->ecol = col;
-	g_object_ref (etgc->ecol);
+	gtk_object_ref (GTK_OBJECT(etgc->ecol));
 	etgc->sort_info = sort_info;
-	g_object_ref (etgc->sort_info);
+	gtk_object_ref (GTK_OBJECT(etgc->sort_info));
 	etgc->n = n;
 	etgc->ascending = column.ascending;
 
@@ -197,7 +197,7 @@ e_table_group_container_new (GnomeCanvasGroup *parent, ETableHeader *full_header
 
 	g_return_val_if_fail (parent != NULL, NULL);
 	
-	etgc = g_object_new (E_TABLE_GROUP_CONTAINER_TYPE, NULL);
+	etgc = gtk_type_new (e_table_group_container_get_type ());
 
 	e_table_group_container_construct (parent, etgc, full_header, header,
 					   model, sort_info, n);
@@ -352,14 +352,14 @@ compute_text (ETableGroupContainer *etgc, ETableGroupContainerChildNode *child_n
 
 	if (etgc->ecol->text) {
 		text = g_strdup_printf ((child_node->count == 1)
-					? _("%s : %s (%d item)")
-					: _("%s : %s (%d items)"),
+					? U_("%s : %s (%d item)")
+					: U_("%s : %s (%d items)"),
 					etgc->ecol->text, child_node->string,
 					(gint) child_node->count);
 	} else {
 		text = g_strdup_printf ((child_node->count == 1)
-					? _("%s (%d item)")
-					: _("%s (%d items)"),
+					? U_("%s (%d item)")
+					: U_("%s (%d items)"),
 					child_node->string,
 					(gint) child_node->count);
 	}
@@ -433,6 +433,7 @@ create_child_node (ETableGroupContainer *etgc, void *val)
 						  NULL);
 	child_node->text = gnome_canvas_item_new (GNOME_CANVAS_GROUP (etgc),
 						  e_text_get_type (),
+						  "font_gdk", etgc->font,
 						  "anchor", GTK_ANCHOR_SW,
 						  "fill_color", "black",
 						  "draw_background", FALSE,
@@ -451,20 +452,20 @@ create_child_node (ETableGroupContainer *etgc, void *val)
 			      "minimum_width", etgc->minimum_width - GROUP_INDENT,
 			      NULL);
 
-	g_signal_connect (child, "cursor_change",
-			  G_CALLBACK (child_cursor_change), etgc);
-	g_signal_connect (child, "cursor_activated",
-			  G_CALLBACK (child_cursor_activated), etgc);
-	g_signal_connect (child, "double_click",
-			  G_CALLBACK (child_double_click), etgc);
-	g_signal_connect (child, "right_click",
-			  G_CALLBACK (child_right_click), etgc);
-	g_signal_connect (child, "click",
-			  G_CALLBACK (child_click), etgc);
-	g_signal_connect (child, "key_press",
-			  G_CALLBACK (child_key_press), etgc);
-	g_signal_connect (child, "start_drag",
-			  G_CALLBACK (child_start_drag), etgc);
+	gtk_signal_connect (GTK_OBJECT (child), "cursor_change",
+			    GTK_SIGNAL_FUNC (child_cursor_change), etgc);
+	gtk_signal_connect (GTK_OBJECT (child), "cursor_activated",
+			    GTK_SIGNAL_FUNC (child_cursor_activated), etgc);
+	gtk_signal_connect (GTK_OBJECT (child), "double_click",
+			    GTK_SIGNAL_FUNC (child_double_click), etgc);
+	gtk_signal_connect (GTK_OBJECT (child), "right_click",
+			    GTK_SIGNAL_FUNC (child_right_click), etgc);
+	gtk_signal_connect (GTK_OBJECT (child), "click",
+			    GTK_SIGNAL_FUNC (child_click), etgc);
+	gtk_signal_connect (GTK_OBJECT (child), "key_press",
+			    GTK_SIGNAL_FUNC (child_key_press), etgc);
+	gtk_signal_connect (GTK_OBJECT (child), "start_drag",
+			    GTK_SIGNAL_FUNC (child_start_drag), etgc);
 	child_node->child = child;
 	child_node->key = e_table_model_duplicate_value (etg->model, etgc->ecol->col_idx, val);
 	child_node->string = e_table_model_value_to_string (etg->model, etgc->ecol->col_idx, val);
@@ -731,112 +732,112 @@ static void etgc_thaw (ETableGroup *etg)
 }
 
 static void
-etgc_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
+etgc_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 {
 	ETableGroup *etg = E_TABLE_GROUP (object);
 	ETableGroupContainer *etgc = E_TABLE_GROUP_CONTAINER (object);
 	GList *list;
 
-	switch (prop_id) {
-	case PROP_FROZEN:
-		if (g_value_get_boolean (value))
+	switch (arg_id) {
+	case ARG_FROZEN:
+		if (GTK_VALUE_BOOL (*arg))
 			etg->frozen = TRUE;
 		else {
 			etg->frozen = FALSE;
 			etgc_thaw (etg);
 		}
 		break;
-	case PROP_MINIMUM_WIDTH:
-	case PROP_WIDTH:
-		etgc->minimum_width = g_value_get_double (value);
+	case ARG_MINIMUM_WIDTH:
+	case ARG_WIDTH:
+		etgc->minimum_width = GTK_VALUE_DOUBLE(*arg);
 
 		for (list = etgc->children; list; list = g_list_next (list)) {
 			ETableGroupContainerChildNode *child_node = (ETableGroupContainerChildNode *)list->data;
-			g_object_set (child_node->child,
-				      "minimum_width", etgc->minimum_width - GROUP_INDENT,
-				      NULL);
+			gtk_object_set (GTK_OBJECT(child_node->child),
+					"minimum_width", etgc->minimum_width - GROUP_INDENT,
+					NULL);
 		}
 		break;
-	case PROP_LENGTH_THRESHOLD:
-		etgc->length_threshold = g_value_get_int (value);
+	case ARG_LENGTH_THRESHOLD:
+		etgc->length_threshold = GTK_VALUE_INT (*arg);
 		for (list = etgc->children; list; list = g_list_next (list)) {
 			ETableGroupContainerChildNode *child_node = (ETableGroupContainerChildNode *)list->data;
-			g_object_set (child_node->child,
-				      "length_threshold", etgc->length_threshold,
-				      NULL);
+			gtk_object_set (GTK_OBJECT(child_node->child),
+					"length_threshold", GTK_VALUE_INT (*arg),
+					NULL);
 		}
 		break;
-	case PROP_UNIFORM_ROW_HEIGHT:
-		etgc->uniform_row_height = g_value_get_boolean (value);
+	case ARG_UNIFORM_ROW_HEIGHT:
+		etgc->uniform_row_height = GTK_VALUE_BOOL (*arg);
 		for (list = etgc->children; list; list = g_list_next (list)) {
 			ETableGroupContainerChildNode *child_node = (ETableGroupContainerChildNode *)list->data;
-			g_object_set (child_node->child,
-				      "uniform_row_height", etgc->uniform_row_height,
-				      NULL);
+			gtk_object_set (GTK_OBJECT(child_node->child),
+					"uniform_row_height", GTK_VALUE_BOOL (*arg),
+					NULL);
 		}
 		break;
 
-	case PROP_SELECTION_MODEL:
+	case ARG_SELECTION_MODEL:
 		if (etgc->selection_model)
-			g_object_unref (etgc->selection_model);
-		etgc->selection_model = E_SELECTION_MODEL(g_value_get_object (value));
+			gtk_object_unref(GTK_OBJECT(etgc->selection_model));
+		etgc->selection_model = E_SELECTION_MODEL(GTK_VALUE_OBJECT (*arg));
 		if (etgc->selection_model)
-			g_object_ref (etgc->selection_model);
+			gtk_object_ref(GTK_OBJECT(etgc->selection_model));
 		for (list = etgc->children; list; list = g_list_next (list)) {
 			ETableGroupContainerChildNode *child_node = (ETableGroupContainerChildNode *)list->data;
-			g_object_set (child_node->child,
-				      "selection_model", etgc->selection_model,
-				      NULL);
+			gtk_object_set (GTK_OBJECT(child_node->child),
+					"selection_model", etgc->selection_model,
+					NULL);
 		}
 		break;
 
-	case PROP_TABLE_ALTERNATING_ROW_COLORS:
-		etgc->alternating_row_colors = g_value_get_boolean (value);
+	case ARG_TABLE_ALTERNATING_ROW_COLORS:
+		etgc->alternating_row_colors = GTK_VALUE_BOOL (*arg);
 		for (list = etgc->children; list; list = g_list_next (list)) {
 			ETableGroupContainerChildNode *child_node = (ETableGroupContainerChildNode *)list->data;
-			g_object_set (child_node->child,
-				      "alternating_row_colors", etgc->alternating_row_colors,
-				      NULL);
+			gtk_object_set (GTK_OBJECT(child_node->child),
+					"alternating_row_colors", GTK_VALUE_BOOL (*arg),
+					NULL);
 		}
 		break;
 
-	case PROP_TABLE_HORIZONTAL_DRAW_GRID:
-		etgc->horizontal_draw_grid = g_value_get_boolean (value);
+	case ARG_TABLE_HORIZONTAL_DRAW_GRID:
+		etgc->horizontal_draw_grid = GTK_VALUE_BOOL (*arg);
 		for (list = etgc->children; list; list = g_list_next (list)) {
 			ETableGroupContainerChildNode *child_node = (ETableGroupContainerChildNode *)list->data;
-			g_object_set (child_node->child,
-				      "horizontal_draw_grid", etgc->horizontal_draw_grid,
-				      NULL);
+			gtk_object_set (GTK_OBJECT(child_node->child),
+					"horizontal_draw_grid", GTK_VALUE_BOOL (*arg),
+					NULL);
 		}
 		break;
 
-	case PROP_TABLE_VERTICAL_DRAW_GRID:
-		etgc->vertical_draw_grid = g_value_get_boolean (value);
+	case ARG_TABLE_VERTICAL_DRAW_GRID:
+		etgc->vertical_draw_grid = GTK_VALUE_BOOL (*arg);
 		for (list = etgc->children; list; list = g_list_next (list)) {
 			ETableGroupContainerChildNode *child_node = (ETableGroupContainerChildNode *)list->data;
-			g_object_set (child_node->child,
-				      "vertical_draw_grid", etgc->vertical_draw_grid,
-				      NULL);
+			gtk_object_set (GTK_OBJECT(child_node->child),
+					"vertical_draw_grid", GTK_VALUE_BOOL (*arg),
+					NULL);
 		}
 		break;
 
-	case PROP_TABLE_DRAW_FOCUS:
-		etgc->draw_focus = g_value_get_boolean (value);
+	case ARG_TABLE_DRAW_FOCUS:
+		etgc->draw_focus = GTK_VALUE_BOOL (*arg);
 		for (list = etgc->children; list; list = g_list_next (list)) {
 			ETableGroupContainerChildNode *child_node = (ETableGroupContainerChildNode *)list->data;
-			g_object_set (child_node->child,
-				      "drawfocus", etgc->draw_focus,
-				      NULL);
+			gtk_object_set (GTK_OBJECT(child_node->child),
+					"drawfocus", GTK_VALUE_BOOL (*arg),
+					NULL);
 		}
 		break;
 
-	case PROP_CURSOR_MODE:
-		etgc->cursor_mode = g_value_get_int (value);
+	case ARG_CURSOR_MODE:
+		etgc->cursor_mode = GTK_VALUE_INT (*arg);
 		for (list = etgc->children; list; list = g_list_next (list)) {
 			ETableGroupContainerChildNode *child_node = (ETableGroupContainerChildNode *)list->data;
-			g_object_set (child_node->child,
-				      "cursor_mode", etgc->cursor_mode,
-				      NULL);
+			gtk_object_set (GTK_OBJECT(child_node->child),
+					"cursor_mode", GTK_VALUE_INT (*arg),
+					NULL);
 		}
 		break;
 	default:
@@ -845,48 +846,48 @@ etgc_set_property (GObject *object, guint prop_id, const GValue *value, GParamSp
 }
 
 static void
-etgc_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
+etgc_get_arg (GtkObject *object, GtkArg *arg, guint arg_id)
 {
 	ETableGroup *etg = E_TABLE_GROUP (object);
 	ETableGroupContainer *etgc = E_TABLE_GROUP_CONTAINER (object);
 
-	switch (prop_id) {
-	case PROP_FROZEN:
-		g_value_set_boolean (value, etg->frozen);
+	switch (arg_id) {
+	case ARG_FROZEN:
+		GTK_VALUE_BOOL (*arg) = etg->frozen;
 		break;
-	case PROP_HEIGHT:
-		g_value_set_double (value, etgc->height);
+	case ARG_HEIGHT:
+		GTK_VALUE_DOUBLE (*arg) = etgc->height;
 		break;
-	case PROP_WIDTH:	
-		g_value_set_double (value, etgc->width);
+	case ARG_WIDTH:	
+		GTK_VALUE_DOUBLE (*arg) = etgc->width;
 		break;
-	case PROP_MINIMUM_WIDTH:
-		g_value_set_double (value, etgc->minimum_width);
+	case ARG_MINIMUM_WIDTH:
+		GTK_VALUE_DOUBLE(*arg) = etgc->minimum_width;
 		break;
-	case PROP_UNIFORM_ROW_HEIGHT:
-		g_value_set_boolean (value, etgc->uniform_row_height);
+	case ARG_UNIFORM_ROW_HEIGHT:
+		GTK_VALUE_BOOL(*arg) = etgc->uniform_row_height;
 		break;
 	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		arg->type = GTK_TYPE_INVALID;
 		break;
 	}
 }
 
 static void
-etgc_class_init (GObjectClass *object_class)
+etgc_class_init (GtkObjectClass *object_class)
 {
 	GnomeCanvasItemClass *item_class = (GnomeCanvasItemClass *) object_class;
 	ETableGroupClass *e_group_class = E_TABLE_GROUP_CLASS(object_class);
 
-	object_class->dispose = etgc_dispose;
-	object_class->set_property = etgc_set_property;
-	object_class->get_property = etgc_get_property;
+	object_class->destroy = etgc_destroy;
+	object_class->set_arg = etgc_set_arg;
+	object_class->get_arg = etgc_get_arg;
 
 	item_class->event = etgc_event;
 	item_class->realize = etgc_realize;
 	item_class->unrealize = etgc_unrealize;
 
-	etgc_parent_class = g_type_class_ref (PARENT_TYPE);
+	etgc_parent_class = gtk_type_class (PARENT_TYPE);
 
 	e_group_class->add = etgc_add;
 	e_group_class->add_array = etgc_add_array;
@@ -901,89 +902,31 @@ etgc_class_init (GObjectClass *object_class)
 	e_group_class->compute_location = etgc_compute_location;
 	e_group_class->get_cell_geometry = etgc_get_cell_geometry;
 
-	g_object_class_install_property (object_class, PROP_TABLE_ALTERNATING_ROW_COLORS,
-					 g_param_spec_boolean ("alternating_row_colors",
-							       _( "Alternating Row Colors" ),
-							       _( "Alternating Row Colors" ), 
-							       FALSE,
-							       G_PARAM_WRITABLE));
+	gtk_object_add_arg_type ("ETableGroupContainer::alternating_row_colors", GTK_TYPE_BOOL,
+				 GTK_ARG_WRITABLE, ARG_TABLE_ALTERNATING_ROW_COLORS);
+	gtk_object_add_arg_type ("ETableGroupContainer::horizontal_draw_grid", GTK_TYPE_BOOL,
+				 GTK_ARG_WRITABLE, ARG_TABLE_HORIZONTAL_DRAW_GRID);
+	gtk_object_add_arg_type ("ETableGroupContainer::vertical_draw_grid", GTK_TYPE_BOOL,
+				 GTK_ARG_WRITABLE, ARG_TABLE_VERTICAL_DRAW_GRID);
+	gtk_object_add_arg_type ("ETableGroupContainer::drawfocus", GTK_TYPE_BOOL,
+				 GTK_ARG_WRITABLE, ARG_TABLE_DRAW_FOCUS);
+	gtk_object_add_arg_type ("ETableGroupContainer::cursor_mode", GTK_TYPE_INT,
+				 GTK_ARG_WRITABLE, ARG_CURSOR_MODE);
+	gtk_object_add_arg_type ("ETableGroupContainer::selection_model", E_SELECTION_MODEL_TYPE,
+				 GTK_ARG_WRITABLE, ARG_SELECTION_MODEL);
+	gtk_object_add_arg_type ("ETableGroupContainer::length_threshold", GTK_TYPE_INT,
+				 GTK_ARG_WRITABLE, ARG_LENGTH_THRESHOLD);
+	gtk_object_add_arg_type ("ETableGroupContainer::uniform_row_height", GTK_TYPE_BOOL,
+				 GTK_ARG_READWRITE, ARG_UNIFORM_ROW_HEIGHT);
 
-	g_object_class_install_property (object_class, PROP_TABLE_HORIZONTAL_DRAW_GRID,
-					 g_param_spec_boolean ("horizontal_draw_grid",
-							       _( "Horizontal Draw Grid" ),
-							       _( "Horizontal Draw Grid" ),
-							       FALSE,
-							       G_PARAM_WRITABLE));
-
-	g_object_class_install_property (object_class, PROP_TABLE_VERTICAL_DRAW_GRID,
-					 g_param_spec_boolean ("vertical_draw_grid",
-							       _( "Vertical Draw Grid" ),
-							       _( "Vertical Draw Grid" ),
-							       FALSE,
-							       G_PARAM_WRITABLE));
-
-	g_object_class_install_property (object_class, PROP_TABLE_DRAW_FOCUS,
-					 g_param_spec_boolean ("drawfocus",
-							       _( "Draw focus" ),
-							       _( "Draw focus" ),
-							       FALSE,
-							       G_PARAM_WRITABLE));
-
-	g_object_class_install_property (object_class, PROP_CURSOR_MODE,
-					 g_param_spec_int ("cursor_mode",
-							   _( "Cursor mode" ),
-							   _( "Cursor mode" ),
-							   E_CURSOR_LINE, E_CURSOR_SPREADSHEET, E_CURSOR_LINE,
-							   G_PARAM_WRITABLE));
-
-	g_object_class_install_property (object_class, PROP_SELECTION_MODEL,
-					 g_param_spec_object ("selection_model",
-							      _( "Selection model" ),
-							      _( "Selection model" ),
-							      E_SELECTION_MODEL_TYPE,
-							      G_PARAM_WRITABLE));
-
-	g_object_class_install_property (object_class, PROP_LENGTH_THRESHOLD,
-					 g_param_spec_int ("length_threshold",
-							   _( "Length Threshold" ),
-							   _( "Length Threshold" ),
-							   0, G_MAXINT, 0,
-							   G_PARAM_READWRITE));
-
-	g_object_class_install_property (object_class, PROP_UNIFORM_ROW_HEIGHT,
-					 g_param_spec_boolean ("uniform_row_height",
-							       _( "Uniform row height" ),
-							       _( "Uniform row height" ),
-							       FALSE,
-							       G_PARAM_READWRITE));
-
-	g_object_class_install_property (object_class, PROP_FROZEN,
-					 g_param_spec_boolean ("frozen",
-							       _( "Frozen" ),
-							       _( "Frozen" ),
-							       FALSE,
-							       G_PARAM_READWRITE));
-
-	g_object_class_install_property (object_class, PROP_HEIGHT,
-					 g_param_spec_double ("height",
-							      _( "Height" ),
-							      _( "Height" ),
-							      0.0, G_MAXDOUBLE, 0.0,
-							      G_PARAM_READWRITE));
-
-	g_object_class_install_property (object_class, PROP_WIDTH,
-					 g_param_spec_double ("width",
-							      _( "Width" ),
-							      _( "Width" ),
-							      0.0, G_MAXDOUBLE, 0.0,
-							      G_PARAM_READWRITE));
-
-	g_object_class_install_property (object_class, PROP_MINIMUM_WIDTH,
-					 g_param_spec_double ("minimum_width",
-							      _( "Minimum width" ),
-							      _( "Minimum Width" ),
-							      0.0, G_MAXDOUBLE, 0.0,
-							      G_PARAM_READWRITE));
+	gtk_object_add_arg_type ("ETableGroupContainer::frozen", GTK_TYPE_BOOL,
+				 GTK_ARG_READWRITE, ARG_FROZEN);
+	gtk_object_add_arg_type ("ETableGroupContainer::height", GTK_TYPE_DOUBLE, 
+				 GTK_ARG_READABLE, ARG_HEIGHT);
+	gtk_object_add_arg_type ("ETableGroupContainer::width", GTK_TYPE_DOUBLE, 
+				 GTK_ARG_READWRITE, ARG_WIDTH);
+	gtk_object_add_arg_type ("ETableGroupContainer::minimum_width", GTK_TYPE_DOUBLE,
+				 GTK_ARG_READWRITE, ARG_MINIMUM_WIDTH);
 }
 
 static void
@@ -992,9 +935,9 @@ etgc_reflow (GnomeCanvasItem *item, gint flags)
 	ETableGroupContainer *etgc = E_TABLE_GROUP_CONTAINER(item);
 	gboolean frozen;
 
-        g_object_get (etgc,
-		      "frozen", &frozen,
-		      NULL);
+        gtk_object_get (GTK_OBJECT(etgc), 
+			"frozen", &frozen,
+			NULL);
 
 	if (frozen)
 		return;
@@ -1026,9 +969,9 @@ etgc_reflow (GnomeCanvasItem *item, gint flags)
 				ETableGroupContainerChildNode *child_node = (ETableGroupContainerChildNode *) list->data;
 				ETableGroup *child = child_node->child;
 				
-				g_object_get (child,
-					      "width", &item_width,
-					      NULL);
+				gtk_object_get (GTK_OBJECT(child),
+						"width", &item_width,
+						NULL);
 
 				if (item_width > running_width)
 					running_width = item_width;
@@ -1036,9 +979,9 @@ etgc_reflow (GnomeCanvasItem *item, gint flags)
 			for ( list = etgc->children; list; list = g_list_next (list)){
 				ETableGroupContainerChildNode *child_node = (ETableGroupContainerChildNode *) list->data;
 				ETableGroup *child = child_node->child;
-				g_object_get (child,
-					      "height", &item_height,
-					      NULL);
+				gtk_object_get (GTK_OBJECT(child),
+						"height", &item_height,
+						NULL);
 				
 				e_canvas_item_move_absolute (GNOME_CANVAS_ITEM(child_node->text),
 							    GROUP_INDENT,
@@ -1085,7 +1028,7 @@ etgc_init (GtkObject *object)
 	container->uniform_row_height = FALSE;
 }
 
-E_MAKE_TYPE (e_table_group_container, "ETableGroupContainer", ETableGroupContainer, etgc_class_init, etgc_init, PARENT_TYPE)
+E_MAKE_TYPE (e_table_group_container, "ETableGroupContainer", ETableGroupContainer, etgc_class_init, etgc_init, PARENT_TYPE);
 
 void
 e_table_group_apply_to_leafs (ETableGroup *etg, ETableGroupLeafFn fn, void *closure)
@@ -1095,7 +1038,7 @@ e_table_group_apply_to_leafs (ETableGroup *etg, ETableGroupLeafFn fn, void *clos
 		GList *list = etgc->children;
 
 		/* Protect from unrefs in the callback functions */
-		g_object_ref (etg);
+		gtk_object_ref (GTK_OBJECT (etg));
 
 		for (list = etgc->children; list; list = list->next){
 			ETableGroupContainerChildNode *child_node = list->data;
@@ -1103,7 +1046,7 @@ e_table_group_apply_to_leafs (ETableGroup *etg, ETableGroupLeafFn fn, void *clos
 			e_table_group_apply_to_leafs (child_node->child, fn, closure);
 		}
 
-		g_object_unref (etg);
+		gtk_object_unref (GTK_OBJECT (etg));
 	} else if (E_IS_TABLE_GROUP_LEAF (etg)){
 		(*fn) (E_TABLE_GROUP_LEAF (etg)->item, closure);
 	} else {
@@ -1174,7 +1117,7 @@ e_table_group_container_print_page  (EPrintable *ep,
 			child_node = child->data;
 		else
 			child_node = NULL;
-		g_object_ref (child_printable);
+		gtk_object_ref(GTK_OBJECT(child_printable));
 	} else {
 		if (!child) {
 			return;
@@ -1182,7 +1125,7 @@ e_table_group_container_print_page  (EPrintable *ep,
 			child_node = child->data;
 			child_printable = e_table_group_get_printable(child_node->child);
 			if (child_printable)
-				g_object_ref (child_printable);
+				gtk_object_ref(GTK_OBJECT(child_printable));
 			e_printable_reset(child_printable);
 		}
 	}
@@ -1286,17 +1229,17 @@ e_table_group_container_print_page  (EPrintable *ep,
 
 		child_node = child->data;
 		if (child_printable)
-			g_object_unref (child_printable);
+			gtk_object_unref(GTK_OBJECT(child_printable));
 		child_printable = e_table_group_get_printable(child_node->child);
 		if (child_printable)
-			g_object_ref (child_printable);
+			gtk_object_ref(GTK_OBJECT(child_printable));
 		e_printable_reset(child_printable);
 	}
 
 	gp_draw_rect(context, 0, height, width, 1);
 
 	if (groupcontext->child_printable)
-		g_object_unref (groupcontext->child_printable);
+		gtk_object_unref(GTK_OBJECT(groupcontext->child_printable));
 	groupcontext->child_printable = child_printable;
 	groupcontext->child = child;
 			
@@ -1306,7 +1249,7 @@ static gboolean
 e_table_group_container_data_left   (EPrintable *ep,
 				     ETGCPrintContext *groupcontext)
 {
-	g_signal_stop_emission_by_name(ep, "data_left");
+	gtk_signal_emit_stop_by_name(GTK_OBJECT(ep), "data_left");
 	return groupcontext->child != NULL;
 }
 
@@ -1316,7 +1259,7 @@ e_table_group_container_reset       (EPrintable *ep,
 {
 	groupcontext->child = groupcontext->etgc->children;
 	if (groupcontext->child_printable)
-		g_object_unref (groupcontext->child_printable);
+		gtk_object_unref(GTK_OBJECT(groupcontext->child_printable));
 	groupcontext->child_printable = NULL;
 }
 
@@ -1339,16 +1282,16 @@ e_table_group_container_height      (EPrintable *ep,
 	child = groupcontext->child;
 
 	if (child_printable)
-		g_object_ref (child_printable);
+		gtk_object_ref(GTK_OBJECT(child_printable));
 	else {
 		if (!child) {
-			g_signal_stop_emission_by_name(ep, "height");
+			gtk_signal_emit_stop_by_name(GTK_OBJECT(ep), "height");
 			return 0;
 		} else {
 			child_node = child->data;
 			child_printable = e_table_group_get_printable(child_node->child);
 			if (child_printable)
-				g_object_ref (child_printable);
+				gtk_object_ref(GTK_OBJECT(child_printable));
 			e_printable_reset(child_printable);
 		}
 	}
@@ -1376,15 +1319,15 @@ e_table_group_container_height      (EPrintable *ep,
 		
 		child_node = child->data;
 		if (child_printable)
-			g_object_unref (child_printable);
+			gtk_object_unref(GTK_OBJECT(child_printable));
 		child_printable = e_table_group_get_printable(child_node->child);
 		if (child_printable)
-			g_object_ref (child_printable);
+			gtk_object_ref(GTK_OBJECT(child_printable));
 		e_printable_reset(child_printable);
 	}
 	if (child_printable)
-		g_object_unref (child_printable);
-	g_signal_stop_emission_by_name(ep, "height");
+		gtk_object_unref(GTK_OBJECT(child_printable));
+	gtk_signal_emit_stop_by_name(GTK_OBJECT(ep), "height");
 	return height;
 }
 
@@ -1407,16 +1350,16 @@ e_table_group_container_will_fit      (EPrintable *ep,
 	child = groupcontext->child;
 
 	if (child_printable)
-		g_object_ref (child_printable);
+		gtk_object_ref(GTK_OBJECT(child_printable));
 	else {
 		if (!child) {
-			g_signal_stop_emission_by_name(ep, "will_fit");
+			gtk_signal_emit_stop_by_name(GTK_OBJECT(ep), "will_fit");
 			return will_fit;
 		} else {
 			child_node = child->data;
 			child_printable = e_table_group_get_printable(child_node->child);
 			if (child_printable)
-				g_object_ref (child_printable);
+				gtk_object_ref(GTK_OBJECT(child_printable));
 			e_printable_reset(child_printable);
 		}
 	}
@@ -1443,31 +1386,28 @@ e_table_group_container_will_fit      (EPrintable *ep,
 			
 			child_node = child->data;
 			if (child_printable)
-				g_object_unref (child_printable);
+				gtk_object_unref(GTK_OBJECT(child_printable));
 			child_printable = e_table_group_get_printable(child_node->child);
 			if (child_printable)
-				g_object_ref (child_printable);
+				gtk_object_ref(GTK_OBJECT(child_printable));
 			e_printable_reset(child_printable);
 		}
 	}
 
 	if (child_printable)
-		g_object_unref (child_printable);
+		gtk_object_unref(GTK_OBJECT(child_printable));
 
-	g_signal_stop_emission_by_name(ep, "will_fit");
+	gtk_signal_emit_stop_by_name(GTK_OBJECT(ep), "will_fit");
 	return will_fit;
 }
 
 static void
-e_table_group_container_printable_destroy (gpointer data,
-					   GObject *where_object_was)
-					   
+e_table_group_container_printable_destroy (GtkObject *object,
+					   ETGCPrintContext *groupcontext)
 {
-	ETGCPrintContext *groupcontext = data;
-
-	g_object_unref (groupcontext->etgc);
+	gtk_object_unref(GTK_OBJECT(groupcontext->etgc));
 	if (groupcontext->child_printable)
-		g_object_ref (groupcontext->child_printable);
+		gtk_object_ref(GTK_OBJECT(groupcontext->child_printable));
 	g_free(groupcontext);
 }
 
@@ -1480,33 +1420,34 @@ etgc_get_printable (ETableGroup *etg)
 
 	groupcontext = g_new(ETGCPrintContext, 1);
 	groupcontext->etgc = etgc;
-	g_object_ref (etgc);
+	gtk_object_ref(GTK_OBJECT(etgc));
 	groupcontext->child = etgc->children;
 	groupcontext->child_printable = NULL;
 
-	g_signal_connect (printable,
-			  "print_page",
-			  G_CALLBACK(e_table_group_container_print_page),
-			  groupcontext);
-	g_signal_connect (printable,
-			  "data_left",
-			  G_CALLBACK(e_table_group_container_data_left),
-			  groupcontext);
-	g_signal_connect (printable,
-			  "reset",
-			  G_CALLBACK(e_table_group_container_reset),
-			  groupcontext);
-	g_signal_connect (printable,
-			  "height",
-			  G_CALLBACK(e_table_group_container_height),
-			  groupcontext);
-	g_signal_connect (printable,
-			  "will_fit",
-			  G_CALLBACK(e_table_group_container_will_fit),
-			  groupcontext);
-	g_object_weak_ref (G_OBJECT (printable),
-			   e_table_group_container_printable_destroy,
-			   groupcontext);
+	gtk_signal_connect (GTK_OBJECT(printable),
+			    "print_page",
+			    GTK_SIGNAL_FUNC(e_table_group_container_print_page),
+			    groupcontext);
+	gtk_signal_connect (GTK_OBJECT(printable),
+			    "data_left",
+			    GTK_SIGNAL_FUNC(e_table_group_container_data_left),
+			    groupcontext);
+	gtk_signal_connect (GTK_OBJECT(printable),
+			    "reset",
+			    GTK_SIGNAL_FUNC(e_table_group_container_reset),
+			    groupcontext);
+	gtk_signal_connect (GTK_OBJECT(printable),
+			    "height",
+			    GTK_SIGNAL_FUNC(e_table_group_container_height),
+			    groupcontext);
+	gtk_signal_connect (GTK_OBJECT(printable),
+			    "will_fit",
+			    GTK_SIGNAL_FUNC(e_table_group_container_will_fit),
+			    groupcontext);
+	gtk_signal_connect (GTK_OBJECT(printable),
+			    "destroy",
+			    GTK_SIGNAL_FUNC(e_table_group_container_printable_destroy),
+			    groupcontext);
 
 	return printable;
 }
