@@ -41,10 +41,13 @@
 #include <libxml/parser.h>
 #include <libxml/xmlmemory.h>
 
+#include <gtk/gtksignal.h>
 #include "gal/util/e-util.h"
 #include "gal/util/e-xml-utils.h"
 #include "e-table-sorting-utils.h"
 
+#define PARENT_TYPE E_TREE_MODEL_TYPE
+
 /* maximum insertions between an idle event that we will do without scheduling an idle sort */
 #define ETS_INSERT_MAX (4)
 
@@ -97,7 +100,6 @@ struct ETreeSortedPriv {
 	int          tree_model_node_inserted_id;
 	int          tree_model_node_removed_id;
 	int          tree_model_node_deleted_id;
-	int          tree_model_node_request_collapse_id;
 
 	int          sort_info_changed_id;
 	int          sort_idle_id;
@@ -111,7 +113,7 @@ struct ETreeSortedPriv {
 enum {
 	ARG_0,
 
-	ARG_SORT_INFO
+	ARG_SORT_INFO,
 };
 
 static void ets_sort_info_changed (ETableSortInfo *sort_info, ETreeSorted *ets);
@@ -138,7 +140,7 @@ ets_sort_idle(gpointer user_data)
 	if (ets->priv->root) {
 		do {
 			ets->priv->nested_resort_idle = FALSE;
-			resort_node (ets, ets->priv->root, FALSE, FALSE, TRUE);
+		resort_node (ets, ets->priv->root, FALSE, FALSE, TRUE);
 		} while (ets->priv->nested_resort_idle);
 	}
 	ets->priv->in_resort_idle = FALSE;
@@ -585,38 +587,39 @@ schedule_resort (ETreeSorted *ets, ETreeSortedPath *path, gboolean needs_regen,
 /* virtual methods */
 
 static void
-ets_dispose (GObject *object)
+ets_destroy (GtkObject *object)
 {
 	ETreeSorted *ets = E_TREE_SORTED (object);
 	ETreeSortedPriv *priv = ets->priv;
 
 	/* FIXME lots of stuff to free here */
 	if (!priv) {
-		G_OBJECT_CLASS (parent_class)->dispose (object);
+		GTK_OBJECT_CLASS (parent_class)->destroy (object);
 		return;
 	}
 
-	if (priv->source) {
-		g_signal_handler_disconnect (G_OBJECT (priv->source),
-				             priv->tree_model_pre_change_id);
-		g_signal_handler_disconnect (G_OBJECT (priv->source),
-				             priv->tree_model_no_change_id);
-		g_signal_handler_disconnect (G_OBJECT (priv->source),
-				             priv->tree_model_node_changed_id);
-		g_signal_handler_disconnect (G_OBJECT (priv->source),
-				             priv->tree_model_node_data_changed_id);
-		g_signal_handler_disconnect (G_OBJECT (priv->source),
-				             priv->tree_model_node_col_changed_id);
-		g_signal_handler_disconnect (G_OBJECT (priv->source),
-				             priv->tree_model_node_inserted_id);
-		g_signal_handler_disconnect (G_OBJECT (priv->source),
-				             priv->tree_model_node_removed_id);
-		g_signal_handler_disconnect (G_OBJECT (priv->source),
-				             priv->tree_model_node_deleted_id);
-		g_signal_handler_disconnect (G_OBJECT (priv->source),
-				             priv->tree_model_node_request_collapse_id);
+	if (priv->root)
+		free_path(priv->root);
 
-		g_object_unref (priv->source);
+	if (priv->source) {
+		gtk_signal_disconnect (GTK_OBJECT (priv->source),
+				       priv->tree_model_pre_change_id);
+		gtk_signal_disconnect (GTK_OBJECT (priv->source),
+				       priv->tree_model_no_change_id);
+		gtk_signal_disconnect (GTK_OBJECT (priv->source),
+				       priv->tree_model_node_changed_id);
+		gtk_signal_disconnect (GTK_OBJECT (priv->source),
+				       priv->tree_model_node_data_changed_id);
+		gtk_signal_disconnect (GTK_OBJECT (priv->source),
+				       priv->tree_model_node_col_changed_id);
+		gtk_signal_disconnect (GTK_OBJECT (priv->source),
+				       priv->tree_model_node_inserted_id);
+		gtk_signal_disconnect (GTK_OBJECT (priv->source),
+				       priv->tree_model_node_removed_id);
+		gtk_signal_disconnect (GTK_OBJECT (priv->source),
+				       priv->tree_model_node_deleted_id);
+
+		gtk_object_unref (GTK_OBJECT (priv->source));
 		priv->source = NULL;
 
 		priv->tree_model_pre_change_id = 0;
@@ -627,16 +630,16 @@ ets_dispose (GObject *object)
 		priv->tree_model_node_inserted_id = 0;
 		priv->tree_model_node_removed_id = 0;
 		priv->tree_model_node_deleted_id = 0;
-		priv->tree_model_node_request_collapse_id = 0;
 	}
 
 	if (priv->sort_info) {
-		g_signal_handler_disconnect (G_OBJECT (priv->sort_info),
-				             priv->sort_info_changed_id);
-		priv->sort_info_changed_id = 0;
+		gtk_signal_disconnect (GTK_OBJECT (priv->sort_info),
+				       priv->sort_info_changed_id);
 
-		g_object_unref (priv->sort_info);
+		gtk_object_unref (GTK_OBJECT (priv->sort_info));
 		priv->sort_info = NULL;
+
+		priv->sort_info_changed_id = 0;
 	}
 
 	ets_stop_sort_idle (ets);
@@ -646,22 +649,71 @@ ets_dispose (GObject *object)
 	}
 
 	if (priv->full_header)
-		g_object_unref(priv->full_header);
+		gtk_object_unref(GTK_OBJECT(priv->full_header));
 
-}
+	g_free (priv);
 
-static void
-ets_finalize (GObject *object)
-{
-	ETreeSorted *ets = (ETreeSorted *) object;
-
-	if (ets->priv->root)
-		free_path(ets->priv->root);
-
-	g_free (ets->priv);
 	ets->priv = NULL;
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	GTK_OBJECT_CLASS (parent_class)->destroy (object);
+}
+
+/* Set_arg handler for the text item */
+static void
+ets_set_arg (GtkObject *object, GtkArg *arg, guint arg_id)
+{
+	ETreeSorted *ets;
+
+	ets = E_TREE_SORTED (object);
+
+	switch (arg_id) {
+	case ARG_SORT_INFO:
+		if (ets->priv->sort_info) {
+			gtk_signal_disconnect (GTK_OBJECT (ets->priv->sort_info),
+					       ets->priv->sort_info_changed_id);
+
+			gtk_object_unref (GTK_OBJECT (ets->priv->sort_info));
+			ets->priv->sort_info_changed_id = 0;
+		}
+		if (GTK_VALUE_OBJECT (*arg))
+			ets->priv->sort_info = E_TABLE_SORT_INFO(GTK_VALUE_OBJECT (*arg));
+		else
+			ets->priv->sort_info = NULL;
+		if (ets->priv->sort_info) {
+			gtk_object_ref(GTK_OBJECT(ets->priv->sort_info));
+
+			ets->priv->sort_info_changed_id = gtk_signal_connect (GTK_OBJECT (ets->priv->sort_info), "sort_info_changed",
+									      GTK_SIGNAL_FUNC (ets_sort_info_changed), ets);
+		}
+		if (ets->priv->root)
+			schedule_resort (ets, ets->priv->root, TRUE, TRUE);
+		break;
+
+	default:
+		return;
+	}
+}
+
+/* Get_arg handler for the text item */
+static void
+ets_get_arg (GtkObject *object, GtkArg *arg, guint arg_id)
+{
+	ETreeSorted *ets;
+
+	ets = E_TREE_SORTED (object);
+
+	switch (arg_id) {
+	case ARG_SORT_INFO:
+		if (ets->priv->sort_info)
+			GTK_VALUE_OBJECT (*arg) = GTK_OBJECT(ets->priv->sort_info);
+		else
+			GTK_VALUE_OBJECT (*arg) = NULL;
+		break;
+
+	default:
+		arg->type = GTK_TYPE_INVALID;
+		break;
+	}
 }
 
 static ETreePath
@@ -944,6 +996,8 @@ ets_value_to_string (ETreeModel *etm, int col, const void *value)
 	return e_tree_model_value_to_string (ets->priv->source, col, value);
 }
 
+
+
 /* Proxy functions */
 
 static void
@@ -972,19 +1026,13 @@ ets_proxy_node_changed (ETreeModel *etm, ETreePath node, ETreeSorted *ets)
 		}
 		ets->priv->root = new_path(NULL, node);
 		e_tree_model_node_changed(E_TREE_MODEL(ets), ets->priv->root);
-		return;
 	} else {
 		ETreeSortedPath *path = find_path(ets, node);
 
 		if (path) {
 			free_children(path);
-			if (!reposition_path(ets, path)) {
-				e_tree_model_node_changed(E_TREE_MODEL(ets), path);
-			} else {
-				e_tree_model_no_change(E_TREE_MODEL(ets));
-			}
-		} else {
-			e_tree_model_no_change(E_TREE_MODEL(ets));
+			if (!reposition_path(ets, path))
+			e_tree_model_node_changed(E_TREE_MODEL(ets), path);
 		}
 	}
 }
@@ -996,9 +1044,7 @@ ets_proxy_node_data_changed (ETreeModel *etm, ETreePath node, ETreeSorted *ets)
 
 	if (path) {
 		if (!reposition_path(ets, path))
-			e_tree_model_node_data_changed(E_TREE_MODEL(ets), path);
-		else
-			e_tree_model_no_change(E_TREE_MODEL(ets));
+		e_tree_model_node_data_changed(E_TREE_MODEL(ets), path);
 	} else
 		e_tree_model_no_change(E_TREE_MODEL(ets));
 }
@@ -1013,9 +1059,7 @@ ets_proxy_node_col_changed (ETreeModel *etm, ETreePath node, int col, ETreeSorte
 		if (e_table_sorting_utils_affects_sort(ets->priv->sort_info, ets->priv->full_header, col))
 			changed = reposition_path(ets, path);
 		if (!changed)
-			e_tree_model_node_col_changed(E_TREE_MODEL(ets), path, col);
-		else
-			e_tree_model_no_change(E_TREE_MODEL(ets));
+		e_tree_model_node_col_changed(E_TREE_MODEL(ets), path, col);
 	} else
 		e_tree_model_no_change(E_TREE_MODEL(ets));
 }
@@ -1080,11 +1124,7 @@ ets_proxy_node_inserted (ETreeModel *etm, ETreePath parent, ETreePath child, ETr
 		if (child) {
 			ets->priv->root = new_path(NULL, child);
 			e_tree_model_node_inserted(E_TREE_MODEL(ets), NULL, ets->priv->root);
-		} else {
-			e_tree_model_no_change(E_TREE_MODEL(ets));
 		}
-	} else {
-		e_tree_model_no_change(E_TREE_MODEL(ets));
 	}
 }
 
@@ -1131,15 +1171,6 @@ ets_proxy_node_deleted (ETreeModel *etm, ETreePath child, ETreeSorted *ets)
 	e_tree_model_node_deleted(E_TREE_MODEL(ets), NULL);
 }
 
-static void
-ets_proxy_node_request_collapse (ETreeModel *etm, ETreePath node, ETreeSorted *ets)
-{
-	ETreeSortedPath *path = find_path(ets, node);
-	if (path) {
-		e_tree_model_node_request_collapse(E_TREE_MODEL(ets), path);
-	}
-}
-
 static void
 ets_sort_info_changed (ETableSortInfo *sort_info, ETreeSorted *ets)
 {
@@ -1154,16 +1185,17 @@ static void
 e_tree_sorted_class_init (ETreeSortedClass *klass)
 {
 	ETreeModelClass *tree_class      = E_TREE_MODEL_CLASS (klass);
-	GObjectClass *object_class       = G_OBJECT_CLASS (klass);
+	GtkObjectClass *object_class     = GTK_OBJECT_CLASS (klass);
 
-	parent_class                     = g_type_class_peek_parent (klass);
+	parent_class                     = gtk_type_class (PARENT_TYPE);
 
 	node_chunk                       = g_mem_chunk_create (ETreeSortedPath, TREEPATH_CHUNK_AREA_SIZE, G_ALLOC_AND_FREE);
 
 	klass->node_resorted             = NULL;
 	
-	object_class->dispose            = ets_dispose;
-	object_class->finalize           = ets_finalize;
+	object_class->destroy            = ets_destroy;
+	object_class->set_arg            = ets_set_arg;
+	object_class->get_arg            = ets_get_arg;
 
 	tree_class->get_root             = ets_get_root;
 	tree_class->get_parent           = ets_get_parent;
@@ -1190,6 +1222,9 @@ e_tree_sorted_class_init (ETreeSortedClass *klass)
 
 	tree_class->has_change_pending   = ets_has_change_pending;
 
+
+
+
 	tree_class->value_at             = ets_value_at;
 	tree_class->set_value_at         = ets_set_value_at;
 	tree_class->is_editable          = ets_is_editable;
@@ -1200,54 +1235,57 @@ e_tree_sorted_class_init (ETreeSortedClass *klass)
 	tree_class->value_is_empty       = ets_value_is_empty;
 	tree_class->value_to_string      = ets_value_to_string;
 
+	gtk_object_add_arg_type ("ETreeSorted::sort_info", E_TABLE_SORT_INFO_TYPE,
+				 GTK_ARG_READWRITE, ARG_SORT_INFO);
+
 	signals [NODE_RESORTED] =
-		g_signal_new ("node_resorted",
-			      E_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ETreeSortedClass, node_resorted),
-			      (GSignalAccumulator) NULL, NULL,
-			      g_cclosure_marshal_VOID__POINTER,
-			      G_TYPE_NONE, 1, G_TYPE_POINTER);
+		gtk_signal_new ("node_resorted",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (ETreeSortedClass, node_resorted),
+				gtk_marshal_NONE__POINTER,
+				GTK_TYPE_NONE, 1, GTK_TYPE_POINTER);
+
+	E_OBJECT_CLASS_ADD_SIGNALS (object_class, signals, LAST_SIGNAL);
 }
 
 static void
-e_tree_sorted_init (GObject *object)
+e_tree_sorted_init (GtkObject *object)
 {
 	ETreeSorted *ets = (ETreeSorted *)object;
 
 	ETreeSortedPriv *priv;
 
-	priv                                      = g_new0 (ETreeSortedPriv, 1);
-	ets->priv                                 = priv;
+	priv                                  = g_new0 (ETreeSortedPriv, 1);
+	ets->priv                             = priv;
 
-	priv->root                                = NULL;
-	priv->source                              = NULL;
+	priv->root                            = NULL;
+	priv->source                          = NULL;
 
-	priv->sort_info                           = NULL;
-	priv->full_header                         = NULL;
+	priv->sort_info                       = NULL;
+	priv->full_header                     = NULL;
 
-	priv->last_access                         = NULL;
+	priv->last_access                     = NULL;
 
-	priv->tree_model_pre_change_id            = 0;
-	priv->tree_model_no_change_id             = 0;
-	priv->tree_model_node_changed_id          = 0;
-	priv->tree_model_node_data_changed_id     = 0;
-	priv->tree_model_node_col_changed_id      = 0;
-	priv->tree_model_node_inserted_id         = 0;
-	priv->tree_model_node_removed_id          = 0;
-	priv->tree_model_node_deleted_id          = 0;
-	priv->tree_model_node_request_collapse_id = 0;
+	priv->tree_model_pre_change_id        = 0;
+	priv->tree_model_no_change_id         = 0;
+	priv->tree_model_node_changed_id      = 0;
+	priv->tree_model_node_data_changed_id = 0;
+	priv->tree_model_node_col_changed_id  = 0;
+	priv->tree_model_node_inserted_id     = 0;
+	priv->tree_model_node_removed_id      = 0;
+	priv->tree_model_node_deleted_id      = 0;
 
-	priv->sort_info_changed_id                = 0;
-	priv->sort_idle_id                        = 0;
-	priv->insert_idle_id                      = 0;
-	priv->insert_count                        = 0;
+	priv->sort_info_changed_id            = 0;
+	priv->sort_idle_id                    = 0;
+	priv->insert_idle_id                  = 0;
+	priv->insert_count                    = 0;
 
-	priv->in_resort_idle                      = 0;
-	priv->nested_resort_idle                  = 0;
+	priv->in_resort_idle                  = 0;
+	priv->nested_resort_idle              = 0;
 }
 
-E_MAKE_TYPE(e_tree_sorted, "ETreeSorted", ETreeSorted, e_tree_sorted_class_init, e_tree_sorted_init, E_TREE_MODEL_TYPE)
+E_MAKE_TYPE(e_tree_sorted, "ETreeSorted", ETreeSorted, e_tree_sorted_class_init, e_tree_sorted_init, PARENT_TYPE)
 
 /**
  * e_tree_sorted_construct:
@@ -1258,35 +1296,34 @@ E_MAKE_TYPE(e_tree_sorted, "ETreeSorted", ETreeSorted, e_tree_sorted_class_init,
 void
 e_tree_sorted_construct (ETreeSorted *ets, ETreeModel *source, ETableHeader *full_header, ETableSortInfo *sort_info)
 {
-	ets->priv->source                              = source;
-	if (source)
-		g_object_ref(source);
+	ets->priv->source      = source;
+	if (source)      gtk_object_ref(GTK_OBJECT(source));
 
-	ets->priv->full_header                         = full_header;
-	if (full_header)
-		g_object_ref(full_header);
+	ets->priv->full_header = full_header;
+	if (full_header) gtk_object_ref(GTK_OBJECT(full_header));
 
-	e_tree_sorted_set_sort_info (ets, sort_info);
+	ets->priv->sort_info   = sort_info;
+	if (sort_info)   gtk_object_ref(GTK_OBJECT(sort_info));
 
-	ets->priv->tree_model_pre_change_id            = g_signal_connect (G_OBJECT (source), "pre_change",
-									   G_CALLBACK (ets_proxy_pre_change), ets);
-	ets->priv->tree_model_no_change_id             = g_signal_connect (G_OBJECT (source), "no_change",
-									   G_CALLBACK (ets_proxy_no_change), ets);
-	ets->priv->tree_model_node_changed_id          = g_signal_connect (G_OBJECT (source), "node_changed",
-									   G_CALLBACK (ets_proxy_node_changed), ets);
-	ets->priv->tree_model_node_data_changed_id     = g_signal_connect (G_OBJECT (source), "node_data_changed",
-									   G_CALLBACK (ets_proxy_node_data_changed), ets);
-	ets->priv->tree_model_node_col_changed_id      = g_signal_connect (G_OBJECT (source), "node_col_changed",
-									   G_CALLBACK (ets_proxy_node_col_changed), ets);
-	ets->priv->tree_model_node_inserted_id         = g_signal_connect (G_OBJECT (source), "node_inserted",
-									   G_CALLBACK (ets_proxy_node_inserted), ets);
-	ets->priv->tree_model_node_removed_id          = g_signal_connect (G_OBJECT (source), "node_removed",
-									   G_CALLBACK (ets_proxy_node_removed), ets);
-	ets->priv->tree_model_node_deleted_id          = g_signal_connect (G_OBJECT (source), "node_deleted",
-									   G_CALLBACK (ets_proxy_node_deleted), ets);
-	ets->priv->tree_model_node_request_collapse_id = g_signal_connect (G_OBJECT (source), "node_request_collapse",
-									   G_CALLBACK (ets_proxy_node_request_collapse), ets);
+	ets->priv->tree_model_pre_change_id      = gtk_signal_connect (GTK_OBJECT (source), "pre_change",
+								       GTK_SIGNAL_FUNC (ets_proxy_pre_change), ets);
+	ets->priv->tree_model_no_change_id         = gtk_signal_connect (GTK_OBJECT (source), "no_change",
+									 GTK_SIGNAL_FUNC (ets_proxy_no_change), ets);
+	ets->priv->tree_model_node_changed_id      = gtk_signal_connect (GTK_OBJECT (source), "node_changed",
+									 GTK_SIGNAL_FUNC (ets_proxy_node_changed), ets);
+	ets->priv->tree_model_node_data_changed_id = gtk_signal_connect (GTK_OBJECT (source), "node_data_changed",
+									 GTK_SIGNAL_FUNC (ets_proxy_node_data_changed), ets);
+	ets->priv->tree_model_node_col_changed_id  = gtk_signal_connect (GTK_OBJECT (source), "node_col_changed",
+									 GTK_SIGNAL_FUNC (ets_proxy_node_col_changed), ets);
+	ets->priv->tree_model_node_inserted_id     = gtk_signal_connect (GTK_OBJECT (source), "node_inserted",
+									 GTK_SIGNAL_FUNC (ets_proxy_node_inserted), ets);
+	ets->priv->tree_model_node_removed_id      = gtk_signal_connect (GTK_OBJECT (source), "node_removed",
+									 GTK_SIGNAL_FUNC (ets_proxy_node_removed), ets);
+	ets->priv->tree_model_node_deleted_id      = gtk_signal_connect (GTK_OBJECT (source), "node_deleted",
+									 GTK_SIGNAL_FUNC (ets_proxy_node_deleted), ets);
 
+	ets->priv->sort_info_changed_id            = gtk_signal_connect (GTK_OBJECT (sort_info), "sort_info_changed",
+									 GTK_SIGNAL_FUNC (ets_sort_info_changed), ets);
 }
 
 /**
@@ -1299,7 +1336,9 @@ e_tree_sorted_construct (ETreeSorted *ets, ETreeModel *source, ETableHeader *ful
 ETreeSorted *
 e_tree_sorted_new (ETreeModel *source, ETableHeader *full_header, ETableSortInfo *sort_info)
 {
-	ETreeSorted *ets = g_object_new (E_TREE_SORTED_TYPE, NULL);
+	ETreeSorted *ets;
+
+	ets = gtk_type_new (e_tree_sorted_get_type ());
 
 	e_tree_sorted_construct(ets, source, full_header, sort_info);
 
@@ -1353,38 +1392,6 @@ e_tree_sorted_node_resorted  (ETreeSorted *sorted, ETreePath node)
 	g_return_if_fail (sorted != NULL);
 	g_return_if_fail (E_IS_TREE_SORTED (sorted));
 	
-	g_signal_emit (G_OBJECT (sorted), signals [NODE_RESORTED], 0, node);
+	gtk_signal_emit (GTK_OBJECT (sorted),
+			 signals [NODE_RESORTED], node);
 }
-
-void
-e_tree_sorted_set_sort_info (ETreeSorted *ets, ETableSortInfo *sort_info)
-{
-
-	g_return_if_fail (ets != NULL);
-
-
-	if (ets->priv->sort_info) {
-		if (ets->priv->sort_info_changed_id != 0)
-			g_signal_handler_disconnect (G_OBJECT (ets->priv->sort_info),
-						     ets->priv->sort_info_changed_id);
-		ets->priv->sort_info_changed_id = 0;
-		g_object_unref (ets->priv->sort_info);
-	}
-
-	ets->priv->sort_info = sort_info;
-	if (sort_info) {
-		g_object_ref(sort_info);
-		ets->priv->sort_info_changed_id = g_signal_connect (G_OBJECT (ets->priv->sort_info), "sort_info_changed",
-								    G_CALLBACK (ets_sort_info_changed), ets);
-	}
-
-	if (ets->priv->root)
-		schedule_resort (ets, ets->priv->root, TRUE, TRUE);
-}
-
-ETableSortInfo*
-e_tree_sorted_get_sort_info (ETreeSorted *ets)
-{
-	return ets->priv->sort_info;
-}
-
