@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/* 
+/*
  * e-completion-view.c - A text completion selection widget
  * Copyright 2000, 2001, Ximian, Inc.
  *
@@ -23,15 +23,11 @@
  */
 
 #include <config.h>
-
-#include "e-completion-view.h"
-
 #include <math.h>
 #include <gdk/gdkkeysyms.h>
 #include <gal/e-table/e-table-simple.h>
 #include <gal/e-table/e-table-scrolled.h>
-#include <gal/util/e-i18n.h>
-#include "gal/util/e-marshal.h"
+#include "e-completion-view.h"
 
 enum {
 	E_COMPLETION_VIEW_NONEMPTY,
@@ -55,9 +51,8 @@ static gint    e_completion_view_key_press_handler (GtkWidget *w, GdkEventKey *k
 
 static void    e_completion_view_class_init (ECompletionViewClass *klass);
 static void    e_completion_view_init       (ECompletionView *completion);
-static void    e_completion_view_dispose    (GObject *object);
+static void    e_completion_view_destroy    (GtkObject *object);
 
-#define PARENT_TYPE GTK_TYPE_EVENT_BOX
 static GtkObjectClass *parent_class;
 
 
@@ -133,7 +128,7 @@ e_completion_view_expose_event (GtkWidget *widget, GdkEventExpose *event)
 		if (bin->child &&
 		    GTK_WIDGET_NO_WINDOW (bin->child) &&
 		    gtk_widget_intersect (bin->child, &event->area, &child_event.area))
-			gtk_widget_send_expose (bin->child, (GdkEvent*) &child_event);
+			gtk_widget_event (bin->child, (GdkEvent*) &child_event);
 	}
 
 	return FALSE;
@@ -195,78 +190,89 @@ e_completion_view_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
 	}
 }
 
-E_MAKE_TYPE (e_completion_view,
-	     "ECompletionView",
-	     ECompletionView,
-	     e_completion_view_class_init,
-	     e_completion_view_init,
-	     PARENT_TYPE)
-	     
+GtkType
+e_completion_view_get_type (void)
+{
+	static GtkType completion_view_type = 0;
+  
+	if (!completion_view_type) {
+		GtkTypeInfo completion_view_info = {
+			"ECompletionView",
+			sizeof (ECompletionView),
+			sizeof (ECompletionViewClass),
+			(GtkClassInitFunc) e_completion_view_class_init,
+			(GtkObjectInitFunc) e_completion_view_init,
+			NULL, NULL, /* reserved */
+			(GtkClassInitFunc) NULL
+		};
+
+		completion_view_type = gtk_type_unique (gtk_event_box_get_type (), &completion_view_info);
+	}
+
+	return completion_view_type;
+}
+
 static void
 e_completion_view_class_init (ECompletionViewClass *klass)
 {
-	GObjectClass *object_class = (GObjectClass *) klass;
+	GtkObjectClass *object_class = (GtkObjectClass *) klass;
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
-	parent_class = g_type_class_ref (PARENT_TYPE);
+	parent_class = GTK_OBJECT_CLASS (gtk_type_class (gtk_event_box_get_type ()));
 
 	e_completion_view_signals[E_COMPLETION_VIEW_NONEMPTY] =
-		g_signal_new ("nonempty",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ECompletionViewClass, nonempty),
-			      NULL, NULL,
-			      e_marshal_NONE__NONE,
-			      G_TYPE_NONE, 0);
+		gtk_signal_new ("nonempty",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (ECompletionViewClass, nonempty),
+				gtk_marshal_NONE__NONE,
+				GTK_TYPE_NONE, 0);
 
 	e_completion_view_signals[E_COMPLETION_VIEW_ADDED] =
-		g_signal_new ("added",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ECompletionViewClass, added),
-			      NULL, NULL,
-			      e_marshal_NONE__NONE,
-			      G_TYPE_NONE, 0);
+		gtk_signal_new ("added",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (ECompletionViewClass, added),
+				gtk_marshal_NONE__NONE,
+				GTK_TYPE_NONE, 0);
 
 	e_completion_view_signals[E_COMPLETION_VIEW_FULL] =
-		g_signal_new ("full",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ECompletionViewClass, full),
-			      NULL, NULL,
-			      e_marshal_NONE__NONE,
-			      G_TYPE_NONE, 0);
+		gtk_signal_new ("full",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (ECompletionViewClass, full),
+				gtk_marshal_NONE__NONE,
+				GTK_TYPE_NONE, 0);
 
 	e_completion_view_signals[E_COMPLETION_VIEW_BROWSE] =
-		g_signal_new ("browse",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ECompletionViewClass, browse),
-			      NULL, NULL,
-			      e_marshal_NONE__POINTER,
-			      G_TYPE_NONE, 1,
-			      G_TYPE_POINTER);
+		gtk_signal_new ("browse",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (ECompletionViewClass, browse),
+				gtk_marshal_NONE__POINTER,
+				GTK_TYPE_NONE, 1,
+				GTK_TYPE_POINTER);
 
 	e_completion_view_signals[E_COMPLETION_VIEW_UNBROWSE] =
-		g_signal_new ("unbrowse",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ECompletionViewClass, unbrowse),
-			      NULL, NULL,
-			      e_marshal_NONE__NONE,
-			      G_TYPE_NONE, 0);
+		gtk_signal_new ("unbrowse",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (ECompletionViewClass, unbrowse),
+				gtk_marshal_NONE__NONE,
+				GTK_TYPE_NONE, 0);
 
 	e_completion_view_signals[E_COMPLETION_VIEW_ACTIVATE] =
-		g_signal_new ("activate",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ECompletionViewClass, activate),
-			      NULL, NULL,
-			      e_marshal_NONE__POINTER,
-			      G_TYPE_NONE, 1,
-			      G_TYPE_POINTER);
+		gtk_signal_new ("activate",
+				GTK_RUN_LAST,
+				E_OBJECT_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (ECompletionViewClass, activate),
+				gtk_marshal_NONE__POINTER,
+				GTK_TYPE_NONE, 1,
+				GTK_TYPE_POINTER);
 
-	object_class->dispose = e_completion_view_dispose;
+	E_OBJECT_CLASS_ADD_SIGNALS (object_class, e_completion_view_signals, E_COMPLETION_VIEW_LAST_SIGNAL);
+
+	object_class->destroy = e_completion_view_destroy;
 
 	widget_class->key_press_event = e_completion_view_local_key_press_handler;
 	widget_class->expose_event = e_completion_view_expose_event;
@@ -282,31 +288,29 @@ e_completion_view_init (ECompletionView *completion)
 }
 
 static void
-e_completion_view_dispose (GObject *object)
+e_completion_view_destroy (GtkObject *object)
 {
 	ECompletionView *cv = E_COMPLETION_VIEW (object);
 
 	e_completion_view_disconnect (cv);
+	e_completion_view_clear_choices (cv);
 
-	if (cv->choices) {
-		e_completion_view_clear_choices (cv);
-
+	if (cv->choices)
 		g_ptr_array_free (cv->choices, TRUE);
-		cv->choices = NULL;
-	}
+	cv->choices = NULL;
 
 	if (cv->key_widget) {
-		g_signal_handler_disconnect (cv->key_widget, cv->key_signal_id);
-		g_object_unref (cv->key_widget);
+		gtk_signal_disconnect (GTK_OBJECT (cv->key_widget), cv->key_signal_id);
+		gtk_object_unref (GTK_OBJECT (cv->key_widget));
 		cv->key_widget = NULL;
 	}
 
 	if (cv->completion)
-		g_object_unref (cv->completion);
+		gtk_object_unref (GTK_OBJECT (cv->completion));
 	cv->completion = NULL;
 
-	if (G_OBJECT_CLASS (parent_class)->dispose)
-		(G_OBJECT_CLASS (parent_class)->dispose) (object);
+	if (parent_class->destroy)
+		(parent_class->destroy) (object);
 }
 
 static void
@@ -316,24 +320,23 @@ e_completion_view_disconnect (ECompletionView *cv)
 	g_return_if_fail (E_IS_COMPLETION_VIEW (cv));
 
 	if (cv->begin_signal_id)
-		g_signal_handler_disconnect (cv->completion, cv->begin_signal_id);
+		gtk_signal_disconnect (GTK_OBJECT (cv->completion), cv->begin_signal_id);
 	if (cv->comp_signal_id)
-		g_signal_handler_disconnect (cv->completion, cv->comp_signal_id);
+		gtk_signal_disconnect (GTK_OBJECT (cv->completion), cv->comp_signal_id);
 	if (cv->restart_signal_id)
-		g_signal_handler_disconnect (cv->completion, cv->restart_signal_id);
+		gtk_signal_disconnect (GTK_OBJECT (cv->completion), cv->restart_signal_id);
 	if (cv->cancel_signal_id)
-		g_signal_handler_disconnect (cv->completion, cv->cancel_signal_id);
+		gtk_signal_disconnect (GTK_OBJECT (cv->completion), cv->cancel_signal_id);
 	if (cv->end_signal_id)
-		g_signal_handler_disconnect (cv->completion, cv->end_signal_id);
+		gtk_signal_disconnect (GTK_OBJECT (cv->completion), cv->end_signal_id);
 	if (cv->clear_signal_id)
-		g_signal_handler_disconnect (cv->completion, cv->clear_signal_id);
+		gtk_signal_disconnect (GTK_OBJECT (cv->completion), cv->clear_signal_id);
 	if (cv->lost_signal_id)
-		g_signal_handler_disconnect (cv->completion, cv->lost_signal_id);
+		gtk_signal_disconnect (GTK_OBJECT (cv->completion), cv->lost_signal_id);
 
 	cv->begin_signal_id   = 0;
 	cv->comp_signal_id    = 0;
 	cv->restart_signal_id = 0;
-	cv->cancel_signal_id   = 0;
 	cv->end_signal_id     = 0;
 	cv->clear_signal_id   = 0;
 	cv->lost_signal_id    = 0;
@@ -441,7 +444,7 @@ e_completion_view_select (ECompletionView *cv, gint r)
 
 	cv->selection = r;
 	e_completion_view_set_cursor_row (cv, r);
-	g_signal_emit (cv, e_completion_view_signals[E_COMPLETION_VIEW_ACTIVATE], 0, match);
+	gtk_signal_emit (GTK_OBJECT (cv), e_completion_view_signals[E_COMPLETION_VIEW_ACTIVATE], match);
 }
 
 static gint
@@ -449,7 +452,7 @@ e_completion_view_key_press_handler (GtkWidget *w, GdkEventKey *key_event, gpoin
 {
 	ECompletionView *cv = E_COMPLETION_VIEW (user_data);
 	gint dir = 0;
-	gboolean key_handled = TRUE, complete_key = FALSE, uncomplete_key = FALSE, is_space = FALSE;
+	gboolean key_handled = TRUE, complete_key = FALSE, uncomplete_key = FALSE;
 
 	/* FIXME: This is totally lame.
 	   The ECompletionView should be able to specify multiple completion/uncompletion keys, or just
@@ -465,14 +468,14 @@ e_completion_view_key_press_handler (GtkWidget *w, GdkEventKey *key_event, gpoin
 	
 	/* Start up a completion.*/
 	if (complete_key && !cv->editable) {
-		g_signal_emit (cv, e_completion_view_signals[E_COMPLETION_VIEW_BROWSE], 0, NULL);
+		gtk_signal_emit (GTK_OBJECT (cv), e_completion_view_signals[E_COMPLETION_VIEW_BROWSE], NULL);
 		goto stop_emission;
 	}
 
 	/* Stop our completion. */
 	if (uncomplete_key && cv->editable && cv->selection < 0) {
 		e_completion_view_set_cursor_row (cv, -1);
-		g_signal_emit (cv, e_completion_view_signals[E_COMPLETION_VIEW_UNBROWSE], 0);
+		gtk_signal_emit (GTK_OBJECT (cv), e_completion_view_signals[E_COMPLETION_VIEW_UNBROWSE]);
 		goto stop_emission;
 	}
 
@@ -504,48 +507,23 @@ e_completion_view_key_press_handler (GtkWidget *w, GdkEventKey *key_event, gpoin
 		break;
 		
 	case GDK_Tab:
-		/* If our cursor is still up in the entry, move down into
-		   the popup.  Otherwise unbrowse. */
-		if (cv->choices->len > 0) {
-			if (cv->selection < 0) {
-				cv->selection = 0;
-				dir = 0;
-			} else {
-				cv->selection = -1;
-				dir = 0;
-				key_handled = FALSE;
-			}
-		}
+		/* Unbrowse, unhandled. */
+		cv->selection = -1;
+		dir = 0;
+		key_handled = FALSE;
 		break;
 
-	case GDK_space:
-	case GDK_KP_Space:
-		is_space = TRUE;
-
 	case GDK_Return:
 	case GDK_KP_Enter:
-		if (cv->selection < 0) {
-			/* We don't have a selection yet, move to the first selection if there is
-			   more than one option.  If there is only one option, select it automatically. */
-
-			/* Let space pass through. */
-			if (is_space)
-				return FALSE;
-			
-			if (cv->choices->len == 1) {
-				e_completion_view_select (cv, 0);
-				goto stop_emission;
-			} else {
-				cv->selection = 0;
-				dir = 0;
-			}
-
-		} else {
-			/* Our cursor is down in the pop-up, so we make our selection. */
+	case GDK_space:
+	case GDK_KP_Space:
+		/* Only handle these key presses if we have an active selection;
+		   otherwise, pass them on. */
+		if (cv->selection >= 0) {
 			e_completion_view_select (cv, cv->selection);
 			goto stop_emission;
 		}
-		break;
+		return FALSE;
 
 	case GDK_Escape:
 		/* Unbrowse hack */
@@ -568,15 +546,15 @@ e_completion_view_key_press_handler (GtkWidget *w, GdkEventKey *key_event, gpoin
 	e_completion_view_set_cursor_row (cv, cv->selection);
 
 	if (cv->selection >= 0)
-		g_signal_emit (cv, e_completion_view_signals[E_COMPLETION_VIEW_BROWSE], 0,
-			       g_ptr_array_index (cv->choices, cv->selection));
+		gtk_signal_emit (GTK_OBJECT (cv), e_completion_view_signals[E_COMPLETION_VIEW_BROWSE], 
+				 g_ptr_array_index (cv->choices, cv->selection));
 	else
-		g_signal_emit (cv, e_completion_view_signals[E_COMPLETION_VIEW_UNBROWSE], 0);
+		gtk_signal_emit (GTK_OBJECT (cv), e_completion_view_signals[E_COMPLETION_VIEW_UNBROWSE]);
 
  stop_emission:
 	
 	if (key_handled)
-		g_signal_stop_emission_by_name (w, "key_press_event");
+		gtk_signal_emit_stop_by_name (GTK_OBJECT (w), "key_press_event");
 
 	return key_handled;
 }
@@ -586,7 +564,6 @@ begin_completion_cb (ECompletion *completion, const gchar *txt, gint pos, gint l
 {
 	ECompletionView *cv = E_COMPLETION_VIEW (user_data);
 
-	e_table_model_pre_change (cv->model);
 	e_completion_view_clear_choices (cv);
 	cv->have_all_choices = FALSE;
 
@@ -606,13 +583,12 @@ cancel_completion_cb (ECompletion *completion, gpointer user_data)
 	ECompletionView *cv = E_COMPLETION_VIEW (user_data);
 
 	/* On a cancel, clear our choices and issue an "unbrowse" signal. */
-	e_table_model_pre_change (cv->model);
 	e_completion_view_clear_choices (cv);
 	cv->have_all_choices = TRUE;
 	e_completion_view_set_cursor_row (cv, -1);
 	e_table_model_changed (cv->model);
 
-	g_signal_emit (cv, e_completion_view_signals[E_COMPLETION_VIEW_UNBROWSE] ,0);
+	gtk_signal_emit (GTK_OBJECT (cv), e_completion_view_signals[E_COMPLETION_VIEW_UNBROWSE]);
 }
 
 static void
@@ -622,17 +598,15 @@ completion_cb (ECompletion *completion, ECompletionMatch *match, gpointer user_d
 	gint r = cv->choices->len;
 	gboolean first = (cv->choices->len == 0);
 
-	e_table_model_pre_change (cv->model);
-
 	e_completion_match_ref (match);
 	g_ptr_array_add (cv->choices, match);
 
 	e_table_model_row_inserted (cv->model, r);
 
 	if (first)
-		g_signal_emit (cv, e_completion_view_signals[E_COMPLETION_VIEW_NONEMPTY], 0);
+		gtk_signal_emit (GTK_OBJECT (cv), e_completion_view_signals[E_COMPLETION_VIEW_NONEMPTY]);
 
-	g_signal_emit (cv, e_completion_view_signals[E_COMPLETION_VIEW_ADDED], 0);
+	gtk_signal_emit (GTK_OBJECT (cv), e_completion_view_signals[E_COMPLETION_VIEW_ADDED]);
 }
 
 static void
@@ -641,11 +615,10 @@ end_completion_cb (ECompletion *completion, gpointer user_data)
 	ECompletionView *cv = E_COMPLETION_VIEW (user_data);
 
 	/* Do a final refresh of the table. */
-	e_table_model_pre_change (cv->model);
 	e_table_model_changed (cv->model);
 
 	cv->have_all_choices = TRUE;
-	g_signal_emit (cv, e_completion_view_signals[E_COMPLETION_VIEW_FULL], 0);
+	gtk_signal_emit (GTK_OBJECT (cv), e_completion_view_signals[E_COMPLETION_VIEW_FULL]);
 }
 
 static void
@@ -653,7 +626,6 @@ clear_completion_cb (ECompletion *completion, gpointer user_data)
 {
 	ECompletionView *cv = E_COMPLETION_VIEW (user_data);
 
-	e_table_model_pre_change (cv->model);
 	e_completion_view_clear_choices (cv);
 	cv->have_all_choices = FALSE;
 
@@ -675,7 +647,6 @@ lost_completion_cb (ECompletion *completion, ECompletionMatch *match, gpointer u
 
 	/* FIXME: do remove_index_fast(), then row_changed and
 	 * row_deleted (if there are more than 1 row still) */
-	e_table_model_pre_change (cv->model);
 	g_ptr_array_remove_index (c, i);
 	e_table_model_row_deleted (cv->model, i);
 	
@@ -685,7 +656,7 @@ lost_completion_cb (ECompletion *completion, ECompletionMatch *match, gpointer u
 /*** Table Callbacks ***/
 
 static char *simple_spec = 
-"<ETableSpecification no-headers=\"true\" draw-grid=\"false\" cursor-mode=\"line\" alternating-row-colors=\"false\" gettext-domain=\"" E_I18N_DOMAIN "\">"
+"<ETableSpecification no-headers=\"true\" draw-grid=\"false\" cursor-mode=\"line\" alternating-row-colors=\"false\">"
 "  <ETableColumn model_col=\"0\" _title=\"Node\" expansion=\"1.0\" "
 "         minimum_width=\"16\" resizable=\"true\" cell=\"string\" "
 "         compare=\"string\"/> "
@@ -753,36 +724,36 @@ e_completion_view_construct (ECompletionView *cv, ECompletion *completion)
 	GTK_WIDGET_SET_FLAGS (GTK_WIDGET (cv), GTK_CAN_FOCUS);
 
 	cv->completion = completion;
-	g_object_ref (completion);
+	gtk_object_ref (GTK_OBJECT (completion));
 
-	cv->begin_signal_id   = g_signal_connect (completion,
-						  "begin_completion",
-						  G_CALLBACK (begin_completion_cb),
-						  cv);
-	cv->comp_signal_id    = g_signal_connect (completion,
-						  "completion",
-						  G_CALLBACK (completion_cb),
-						  cv);
-	cv->restart_signal_id = g_signal_connect (completion,
-						  "restart_completion",
-						  G_CALLBACK (restart_completion_cb),
-						  cv);
-	cv->cancel_signal_id  = g_signal_connect (completion,
-						  "cancel_completion",
-						  G_CALLBACK (cancel_completion_cb),
-						  cv);
-	cv->end_signal_id     = g_signal_connect (completion,
-						  "end_completion",
-						  G_CALLBACK (end_completion_cb),
-						  cv);
-	cv->clear_signal_id   = g_signal_connect (completion,
-						  "clear_completion",
-						  G_CALLBACK (clear_completion_cb),
-						  cv);
-	cv->lost_signal_id    = g_signal_connect (completion,
-						  "lost_completion",
-						  G_CALLBACK (lost_completion_cb),
-						  cv);
+	cv->begin_signal_id   = gtk_signal_connect (GTK_OBJECT (completion),
+						    "begin_completion",
+						    GTK_SIGNAL_FUNC (begin_completion_cb),
+						    cv);
+	cv->comp_signal_id    = gtk_signal_connect (GTK_OBJECT (completion),
+						    "completion",
+						    GTK_SIGNAL_FUNC (completion_cb),
+						    cv);
+	cv->restart_signal_id = gtk_signal_connect (GTK_OBJECT (completion),
+						    "restart_completion",
+						    GTK_SIGNAL_FUNC (restart_completion_cb),
+						    cv);
+	cv->cancel_signal_id  = gtk_signal_connect (GTK_OBJECT (completion),
+						    "cancel_completion",
+						    GTK_SIGNAL_FUNC (cancel_completion_cb),
+						    cv);
+	cv->end_signal_id     = gtk_signal_connect (GTK_OBJECT (completion),
+						    "end_completion",
+						    GTK_SIGNAL_FUNC (end_completion_cb),
+						    cv);
+	cv->clear_signal_id   = gtk_signal_connect (GTK_OBJECT (completion),
+						    "clear_completion",
+						    GTK_SIGNAL_FUNC (clear_completion_cb),
+						    cv);
+	cv->lost_signal_id    = gtk_signal_connect (GTK_OBJECT (completion),
+						    "lost_completion",
+						    GTK_SIGNAL_FUNC (lost_completion_cb),
+						    cv);
 
 	cv->model = e_table_simple_new (table_col_count,
 					table_row_count,
@@ -799,7 +770,7 @@ e_completion_view_construct (ECompletionView *cv, ECompletion *completion)
 					cv);
 
 	cv->table = e_table_scrolled_new (cv->model, NULL, simple_spec, NULL);
-	g_object_unref (cv->model);
+	gtk_object_unref (GTK_OBJECT (cv->model));
 
 	e_scroll_frame_set_shadow_type (E_SCROLL_FRAME (cv->table), GTK_SHADOW_NONE);
 	e_scroll_frame_set_scrollbar_spacing (E_SCROLL_FRAME (cv->table), 0);
@@ -808,10 +779,10 @@ e_completion_view_construct (ECompletionView *cv, ECompletion *completion)
 	gtk_container_add (GTK_CONTAINER (cv), cv->table);
 	gtk_widget_show_all (cv->table);
 
-	g_signal_connect (e_completion_view_table (cv),
-			  "click",
-			  G_CALLBACK (table_click_cb),
-			  cv);
+	gtk_signal_connect (GTK_OBJECT (e_completion_view_table (cv)),
+			    "click",
+			    GTK_SIGNAL_FUNC (table_click_cb),
+			    cv);
 
 	cv->selection = -1;
 }
@@ -824,7 +795,7 @@ e_completion_view_new (ECompletion *completion)
 	g_return_val_if_fail (completion != NULL, NULL);
 	g_return_val_if_fail (E_IS_COMPLETION (completion), NULL);
 
-	p = g_object_new (E_COMPLETION_VIEW_TYPE, NULL);
+	p = gtk_type_new (e_completion_view_get_type ());
 
 	e_completion_view_construct (E_COMPLETION_VIEW (p), completion);
 
@@ -839,18 +810,18 @@ e_completion_view_connect_keys (ECompletionView *cv, GtkWidget *w)
 	g_return_if_fail (w == NULL || GTK_IS_WIDGET (w));
 
 	if (cv->key_widget) {
-		g_signal_handler_disconnect (cv->key_widget, cv->key_signal_id);
-		g_object_unref (cv->key_widget);
+		gtk_signal_disconnect (GTK_OBJECT (cv->key_widget), cv->key_signal_id);
+		gtk_object_unref (GTK_OBJECT (cv->key_widget));
 	}
 
 	if (w) {
 		cv->key_widget = w;
-		g_object_ref (w);
+		gtk_object_ref (GTK_OBJECT (w));
 
-		cv->key_signal_id = g_signal_connect (w,
-						      "key_press_event",
-						      G_CALLBACK (e_completion_view_key_press_handler),
-						      cv);
+		cv->key_signal_id = gtk_signal_connect (GTK_OBJECT (w),
+							"key_press_event",
+							GTK_SIGNAL_FUNC (e_completion_view_key_press_handler),
+							cv);
 	} else {
 		cv->key_widget = NULL;
 		cv->key_signal_id = 0;
