@@ -30,9 +30,7 @@
 #include <gtk/gtkarrow.h>
 #include <gtk/gtkbutton.h>
 #include <gtk/gtksignal.h>
-#include <gtk/gtkeventbox.h>
 #include "e-vscrolled-bar.h"
-#include <gal/util/e-util.h>
 
 /* These are the offsets of the up & down buttons from the right and top/bottom
    of the widget. */
@@ -44,7 +42,7 @@
 
 static void e_vscrolled_bar_class_init (EVScrolledBarClass *class);
 static void e_vscrolled_bar_init (EVScrolledBar *vscrolled_bar);
-static void e_vscrolled_bar_dispose (GObject *object);
+static void e_vscrolled_bar_destroy (GtkObject *object);
 static void e_vscrolled_bar_finalize (GObject *object);
 static void e_vscrolled_bar_map (GtkWidget *widget);
 static void e_vscrolled_bar_unmap (GtkWidget *widget);
@@ -52,8 +50,6 @@ static void e_vscrolled_bar_size_request (GtkWidget      *widget,
 					  GtkRequisition *requisition);
 static void e_vscrolled_bar_size_allocate (GtkWidget *widget,
 					   GtkAllocation *allocation);
-static int  e_vscrolled_bar_expose (GtkWidget      *widget,
-				    GdkEventExpose *event);
 static gint e_vscrolled_bar_button_press   (GtkWidget        *widget,
 					    GdkEventButton   *event);
 static void e_vscrolled_bar_add (GtkContainer *container,
@@ -75,40 +71,56 @@ static void e_vscrolled_bar_button_clicked (GtkWidget *button,
 static gboolean e_vscrolled_bar_scroll (gpointer data);
 static gboolean e_vscrolled_bar_timeout_handler (gpointer data);
 
-#define PARENT_TYPE GTK_TYPE_BIN
+
 static GtkBinClass *parent_class;
 
 
-E_MAKE_TYPE (e_vscrolled_bar,
-	     "EVScrolledBar",
-	     EVScrolledBar,
-	     e_vscrolled_bar_class_init,
-	     e_vscrolled_bar_init,
-	     PARENT_TYPE)
+GtkType
+e_vscrolled_bar_get_type (void)
+{
+	static GtkType e_vscrolled_bar_type = 0;
+
+	if (!e_vscrolled_bar_type) {
+		GtkTypeInfo e_vscrolled_bar_info = {
+			"EVScrolledBar",
+			sizeof (EVScrolledBar),
+			sizeof (EVScrolledBarClass),
+			(GtkClassInitFunc) e_vscrolled_bar_class_init,
+			(GtkObjectInitFunc) e_vscrolled_bar_init,
+			NULL, /* reserved 1 */
+			NULL, /* reserved 2 */
+			(GtkClassInitFunc) NULL
+		};
+
+		parent_class = gtk_type_class (GTK_TYPE_BIN);
+		e_vscrolled_bar_type = gtk_type_unique (GTK_TYPE_BIN,
+							&e_vscrolled_bar_info);
+	}
+
+	return e_vscrolled_bar_type;
+}
+
 
 static void
 e_vscrolled_bar_class_init (EVScrolledBarClass *class)
 {
-	GObjectClass *object_class;
+	GtkObjectClass *object_class;
 	GtkWidgetClass *widget_class;
 	GtkContainerClass *container_class;
 
-	parent_class = g_type_class_ref (PARENT_TYPE);
-
-	object_class = (GObjectClass *) class;
+	object_class = (GtkObjectClass *) class;
 	widget_class = (GtkWidgetClass *) class;
 	container_class = (GtkContainerClass *) class;
 
 	/* Method override */
-	object_class->dispose		= e_vscrolled_bar_dispose;
-	object_class->finalize          = e_vscrolled_bar_finalize;
+	object_class->destroy		= e_vscrolled_bar_destroy;
+	G_OBJECT_CLASS (object_class)->finalize = e_vscrolled_bar_finalize;
 
 	widget_class->map		= e_vscrolled_bar_map;
 	widget_class->unmap		= e_vscrolled_bar_unmap;
 	widget_class->size_request	= e_vscrolled_bar_size_request;
  	widget_class->size_allocate	= e_vscrolled_bar_size_allocate;
 	widget_class->button_press_event= e_vscrolled_bar_button_press;
-	widget_class->expose_event      = e_vscrolled_bar_expose;
 
 	container_class->add		= e_vscrolled_bar_add;
 	container_class->remove		= e_vscrolled_bar_remove;
@@ -126,48 +138,35 @@ e_vscrolled_bar_init (EVScrolledBar *vscrolled_bar)
 	gtk_container_set_resize_mode (GTK_CONTAINER (vscrolled_bar),
 				       GTK_RESIZE_QUEUE);
 
-	gtk_widget_set_redraw_on_allocate (GTK_WIDGET (vscrolled_bar), TRUE);
-
 	gtk_widget_push_composite_child ();
 
-	vscrolled_bar->up_ebox = gtk_event_box_new ();
 	vscrolled_bar->up_button = gtk_button_new ();
 	gtk_widget_set_composite_name (vscrolled_bar->up_button,
 				       "up_button");
-	gtk_widget_set_parent (vscrolled_bar->up_ebox, GTK_WIDGET (vscrolled_bar));
+	gtk_widget_set_parent (vscrolled_bar->up_button,
+			       GTK_WIDGET (vscrolled_bar));
 	arrow = gtk_arrow_new (GTK_ARROW_UP, GTK_SHADOW_OUT);
 	gtk_misc_set_padding (GTK_MISC (arrow), 1, 1);
 	gtk_widget_show (arrow);
 	gtk_container_add (GTK_CONTAINER (vscrolled_bar->up_button), arrow);
 	gtk_widget_show (vscrolled_bar->up_button);
-	gtk_container_add (GTK_CONTAINER (vscrolled_bar->up_ebox), vscrolled_bar->up_button);
-	gtk_widget_show (vscrolled_bar->up_ebox);
-	g_signal_connect_after (vscrolled_bar->up_button, "pressed",
-				G_CALLBACK (e_vscrolled_bar_button_pressed), vscrolled_bar);
-	g_signal_connect_after (vscrolled_bar->up_button, "released",
-				G_CALLBACK (e_vscrolled_bar_button_released), vscrolled_bar);
-	g_signal_connect (vscrolled_bar->up_button, "clicked",
-			  G_CALLBACK (e_vscrolled_bar_button_clicked), vscrolled_bar);
+	gtk_signal_connect_after (GTK_OBJECT (vscrolled_bar->up_button), "pressed", GTK_SIGNAL_FUNC (e_vscrolled_bar_button_pressed), vscrolled_bar);
+	gtk_signal_connect_after (GTK_OBJECT (vscrolled_bar->up_button), "released", GTK_SIGNAL_FUNC (e_vscrolled_bar_button_released), vscrolled_bar);
+	gtk_signal_connect (GTK_OBJECT (vscrolled_bar->up_button), "clicked", GTK_SIGNAL_FUNC (e_vscrolled_bar_button_clicked), vscrolled_bar);
 
-	vscrolled_bar->down_ebox = gtk_event_box_new ();
 	vscrolled_bar->down_button = gtk_button_new ();
 	gtk_widget_set_composite_name (vscrolled_bar->up_button,
 				       "down_button");
-	gtk_widget_set_parent (vscrolled_bar->down_ebox,
+	gtk_widget_set_parent (vscrolled_bar->down_button,
 			       GTK_WIDGET (vscrolled_bar));
 	arrow = gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_OUT);
 	gtk_misc_set_padding (GTK_MISC (arrow), 1, 1);
 	gtk_widget_show (arrow);
 	gtk_container_add (GTK_CONTAINER (vscrolled_bar->down_button), arrow);
 	gtk_widget_show (vscrolled_bar->down_button);
-	gtk_container_add (GTK_CONTAINER (vscrolled_bar->down_ebox), vscrolled_bar->down_button);
-	gtk_widget_show (vscrolled_bar->down_ebox);
-	g_signal_connect_after (vscrolled_bar->down_button, "pressed",
-				G_CALLBACK (e_vscrolled_bar_button_pressed), vscrolled_bar);
-	g_signal_connect_after (vscrolled_bar->down_button, "released",
-				G_CALLBACK (e_vscrolled_bar_button_released), vscrolled_bar);
-	g_signal_connect (vscrolled_bar->down_button, "clicked",
-			  G_CALLBACK (e_vscrolled_bar_button_clicked), vscrolled_bar);
+	gtk_signal_connect_after (GTK_OBJECT (vscrolled_bar->down_button), "pressed", GTK_SIGNAL_FUNC (e_vscrolled_bar_button_pressed), vscrolled_bar);
+	gtk_signal_connect_after (GTK_OBJECT (vscrolled_bar->down_button), "released", GTK_SIGNAL_FUNC (e_vscrolled_bar_button_released), vscrolled_bar);
+	gtk_signal_connect (GTK_OBJECT (vscrolled_bar->down_button), "clicked", GTK_SIGNAL_FUNC (e_vscrolled_bar_button_clicked), vscrolled_bar);
 
 	gtk_widget_pop_composite_child ();
 
@@ -192,7 +191,7 @@ e_vscrolled_bar_new (GtkAdjustment *adjustment)
 {
 	GtkWidget *vscrolled_bar;
 
-	vscrolled_bar = GTK_WIDGET (g_object_new (E_VSCROLLED_BAR_TYPE, NULL));
+	vscrolled_bar = GTK_WIDGET (gtk_type_new (e_vscrolled_bar_get_type ()));
 	e_vscrolled_bar_set_adjustment (E_VSCROLLED_BAR (vscrolled_bar),
 					adjustment);
 
@@ -201,7 +200,7 @@ e_vscrolled_bar_new (GtkAdjustment *adjustment)
 
 
 static void
-e_vscrolled_bar_dispose (GObject *object)
+e_vscrolled_bar_destroy (GtkObject *object)
 {
 	EVScrolledBar *vscrolled_bar;
 
@@ -212,15 +211,15 @@ e_vscrolled_bar_dispose (GObject *object)
 		vscrolled_bar->timeout_id = 0;
 	}
 
-	if (vscrolled_bar->up_ebox)
-		gtk_widget_unparent (vscrolled_bar->up_ebox);
-	vscrolled_bar->up_ebox = NULL;
+	if (vscrolled_bar->up_button)
+		gtk_widget_unparent (vscrolled_bar->up_button);
+	vscrolled_bar->up_button = NULL;
 
-	if (vscrolled_bar->down_ebox)
-		gtk_widget_unparent (vscrolled_bar->down_ebox);
-	vscrolled_bar->down_ebox = NULL;
+	if (vscrolled_bar->down_button)
+		gtk_widget_unparent (vscrolled_bar->down_button);
+	vscrolled_bar->down_button = NULL;
 
-	G_OBJECT_CLASS (parent_class)->dispose (object);
+	GTK_OBJECT_CLASS (parent_class)->destroy (object);
 }
 
 
@@ -231,7 +230,7 @@ e_vscrolled_bar_finalize (GObject *object)
 
 	vscrolled_bar = E_VSCROLLED_BAR (object);
 
-	g_object_unref (vscrolled_bar->adjustment);
+	gtk_object_unref (GTK_OBJECT (vscrolled_bar->adjustment));
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -253,15 +252,15 @@ e_vscrolled_bar_map (GtkWidget *widget)
   
 	adjustment = vscrolled_bar->adjustment;
 
-	if (GTK_WIDGET_VISIBLE (vscrolled_bar->up_ebox)
+	if (GTK_WIDGET_VISIBLE (vscrolled_bar->up_button)
 	    && adjustment->value != adjustment->lower
-	    && !GTK_WIDGET_MAPPED (vscrolled_bar->up_ebox))
-		gtk_widget_map (vscrolled_bar->up_ebox);
-	
-	if (GTK_WIDGET_VISIBLE (vscrolled_bar->down_ebox)
+	    && !GTK_WIDGET_MAPPED (vscrolled_bar->up_button))
+		gtk_widget_map (vscrolled_bar->up_button);
+  
+	if (GTK_WIDGET_VISIBLE (vscrolled_bar->down_button)
 	    && adjustment->value < adjustment->upper - adjustment->page_size
-	    && !GTK_WIDGET_MAPPED (vscrolled_bar->down_ebox))
-		gtk_widget_map (vscrolled_bar->down_ebox);
+	    && !GTK_WIDGET_MAPPED (vscrolled_bar->down_button))
+		gtk_widget_map (vscrolled_bar->down_button);
 }
 
 
@@ -278,11 +277,11 @@ e_vscrolled_bar_unmap (GtkWidget *widget)
 	/* chain parent class handler to unmap self and child */
 	GTK_WIDGET_CLASS (parent_class)->unmap (widget);
   
-	if (GTK_WIDGET_MAPPED (vscrolled_bar->up_ebox))
-		gtk_widget_unmap (vscrolled_bar->up_ebox);
+	if (GTK_WIDGET_MAPPED (vscrolled_bar->up_button))
+		gtk_widget_unmap (vscrolled_bar->up_button);
   
-	if (GTK_WIDGET_MAPPED (vscrolled_bar->down_ebox))
-		gtk_widget_unmap (vscrolled_bar->down_ebox);
+	if (GTK_WIDGET_MAPPED (vscrolled_bar->down_button))
+		gtk_widget_unmap (vscrolled_bar->down_button);
 }
 
 
@@ -312,12 +311,12 @@ e_vscrolled_bar_size_request (GtkWidget      *widget,
 	}
 
 	/* We remember the requested heights of the up & down buttons. */
-	gtk_widget_size_request (vscrolled_bar->up_ebox,
+	gtk_widget_size_request (vscrolled_bar->up_button,
 				 &child_requisition);
 	vscrolled_bar->up_button_width = child_requisition.width;
 	vscrolled_bar->up_button_height = child_requisition.height;
 
-	gtk_widget_size_request (vscrolled_bar->down_ebox,
+	gtk_widget_size_request (vscrolled_bar->down_button,
 				 &child_requisition);
 	vscrolled_bar->down_button_width = child_requisition.width;
 	vscrolled_bar->down_button_height = child_requisition.height;
@@ -348,51 +347,62 @@ e_vscrolled_bar_size_allocate (GtkWidget *widget,
 
 	border_width = GTK_CONTAINER (widget)->border_width;
 
-	child_allocation.x = allocation->x + border_width;
-	child_allocation.y = allocation->y + border_width;
+	child_allocation.x = border_width;
+	child_allocation.y = border_width;
 	child_allocation.width = allocation->width - 2 * border_width;
 	child_allocation.height = allocation->height - 2 * border_width;
 	gtk_widget_size_allocate (bin->child, &child_allocation);
 
-	button_allocation.x = allocation->x + allocation->width - border_width
+	button_allocation.x = allocation->width - border_width
 		- vscrolled_bar->up_button_width
 		- E_VSCROLLED_BAR_BUTTON_X_OFFSET;
-	button_allocation.y = allocation->y + border_width + E_VSCROLLED_BAR_BUTTON_Y_OFFSET;
+	button_allocation.y = border_width + E_VSCROLLED_BAR_BUTTON_Y_OFFSET;
 	button_allocation.width = vscrolled_bar->up_button_width;
 	button_allocation.height = vscrolled_bar->up_button_height;
-	gtk_widget_size_allocate (vscrolled_bar->up_ebox,
+	gtk_widget_size_allocate (vscrolled_bar->up_button,
 				  &button_allocation);
 
-	button_allocation.x = allocation->x + allocation->width - border_width
+	button_allocation.x = allocation->width - border_width
 		- vscrolled_bar->down_button_width
 		- E_VSCROLLED_BAR_BUTTON_X_OFFSET;
-	button_allocation.y = allocation->y + allocation->height - border_width
+	button_allocation.y = allocation->height - border_width
 		- vscrolled_bar->down_button_height
 		- E_VSCROLLED_BAR_BUTTON_Y_OFFSET;
 	button_allocation.width = vscrolled_bar->down_button_width;
 	button_allocation.height = vscrolled_bar->down_button_height;
-	gtk_widget_size_allocate (vscrolled_bar->down_ebox,
+	gtk_widget_size_allocate (vscrolled_bar->down_button,
 				  &button_allocation);
 }
 
-static int
-e_vscrolled_bar_expose (GtkWidget      *widget,
-			GdkEventExpose *event)
+#if 0
+static void
+e_vscrolled_bar_draw (GtkWidget    *widget,
+		      GdkRectangle *area)
 {
-	EVScrolledBar *vscrolled_bar = E_VSCROLLED_BAR (widget);
-	GtkContainer *container = GTK_CONTAINER (vscrolled_bar);
-	GtkAdjustment *adjustment = vscrolled_bar->adjustment;
+	EVScrolledBar *vscrolled_bar;
+	GtkBin *bin;
+	GdkRectangle child_area;
 
-	if (GTK_BIN (vscrolled_bar)->child != NULL)
-		gtk_container_propagate_expose (container, GTK_BIN (vscrolled_bar)->child, event);
+	g_return_if_fail (widget != NULL);
+	g_return_if_fail (E_IS_VSCROLLED_BAR (widget));
+	g_return_if_fail (area != NULL);
+  
+	vscrolled_bar = E_VSCROLLED_BAR (widget);
+	bin = GTK_BIN (widget);
 
-	if (adjustment->value != adjustment->lower)
-		gtk_container_propagate_expose (container, vscrolled_bar->up_ebox, event);
-	if (adjustment->value < adjustment->upper - adjustment->page_size)
-		gtk_container_propagate_expose (container, vscrolled_bar->down_ebox, event);
-
-	return FALSE;
+	if (bin->child && GTK_WIDGET_VISIBLE (bin->child) &&
+	    gtk_widget_intersect (bin->child, area, &child_area))
+		gtk_widget_draw (bin->child, &child_area);
+  
+	if (GTK_WIDGET_DRAWABLE (vscrolled_bar->up_button) &&
+	    gtk_widget_intersect (vscrolled_bar->up_button, area, &child_area))
+		gtk_widget_draw (vscrolled_bar->up_button, &child_area);
+  
+	if (GTK_WIDGET_DRAWABLE (vscrolled_bar->down_button) &&
+	    gtk_widget_intersect (vscrolled_bar->down_button, area, &child_area))
+		gtk_widget_draw (vscrolled_bar->down_button, &child_area);
 }
+#endif
 
 static gint
 e_vscrolled_bar_button_press (GtkWidget      *widget,
@@ -422,8 +432,8 @@ e_vscrolled_bar_button_press (GtkWidget      *widget,
 
 	if (adjustment->value != new_value) {
 		adjustment->value = new_value;
-		g_signal_emit_by_name (adjustment,
-				       "value_changed");
+		gtk_signal_emit_by_name (GTK_OBJECT (adjustment),
+					 "value_changed");
 		return TRUE;
 	}
 
@@ -494,6 +504,16 @@ e_vscrolled_bar_forall (GtkContainer *container,
 						    include_internals,
 						    callback,
 						    callback_data);
+	if (include_internals) {
+		EVScrolledBar *vscrolled_bar;
+
+		vscrolled_bar = E_VSCROLLED_BAR (container);
+      
+		if (vscrolled_bar->up_button)
+			callback (vscrolled_bar->up_button, callback_data);
+		if (vscrolled_bar->down_button)
+			callback (vscrolled_bar->down_button, callback_data);
+	}
 }
 
 
@@ -533,34 +553,32 @@ e_vscrolled_bar_set_adjustment (EVScrolledBar     *vscrolled_bar,
 	if (adjustment)
 		g_return_if_fail (GTK_IS_ADJUSTMENT (adjustment));
 	else
-		adjustment = (GtkAdjustment*) g_object_new (GTK_TYPE_ADJUSTMENT, NULL);
+		adjustment = (GtkAdjustment*) gtk_object_new (GTK_TYPE_ADJUSTMENT, NULL);
 
 	if (vscrolled_bar->adjustment == adjustment)
 		return;
 
 	if (vscrolled_bar->adjustment) {
-		g_signal_handlers_disconnect_matched (vscrolled_bar->adjustment,
-						      G_SIGNAL_MATCH_FUNC,
-						      0, 0, 0,
-						      e_vscrolled_bar_adjustment_changed,
-						      NULL);
-		g_object_unref (vscrolled_bar->adjustment);
+		gtk_signal_disconnect_by_func (GTK_OBJECT (vscrolled_bar->adjustment),
+					       GTK_SIGNAL_FUNC (e_vscrolled_bar_adjustment_changed),
+					       vscrolled_bar);
+		gtk_object_unref (GTK_OBJECT (vscrolled_bar->adjustment));
 	}
 
 	vscrolled_bar->adjustment = adjustment;
-	g_object_ref (vscrolled_bar->adjustment);
+	gtk_object_ref (GTK_OBJECT (vscrolled_bar->adjustment));
 	gtk_object_sink (GTK_OBJECT (vscrolled_bar->adjustment));
 
 	/* I've used connect_after here to avoid a problem when using a
 	   GnomeCanvas as the child widget. When just using connect it would
 	   leave a blank space when one of the buttons is hidden. We want
 	   the GtkLayout to handle the scrolling before we hide any buttons. */
-	g_signal_connect_after (adjustment, "changed",
-				G_CALLBACK (e_vscrolled_bar_adjustment_changed),
-				vscrolled_bar);
-	g_signal_connect_after (adjustment, "value_changed",
-				G_CALLBACK (e_vscrolled_bar_adjustment_changed),
-				vscrolled_bar);
+	gtk_signal_connect_after (GTK_OBJECT (adjustment), "changed",
+				  GTK_SIGNAL_FUNC (e_vscrolled_bar_adjustment_changed),
+				  vscrolled_bar);
+	gtk_signal_connect_after (GTK_OBJECT (adjustment), "value_changed",
+				  GTK_SIGNAL_FUNC (e_vscrolled_bar_adjustment_changed),
+				  vscrolled_bar);
 
 	e_vscrolled_bar_adjustment_changed (adjustment, vscrolled_bar);
 
@@ -577,7 +595,9 @@ e_vscrolled_bar_adjustment_changed (GtkAdjustment *adjustment,
 
 	g_return_if_fail (adjustment != NULL);
 	g_return_if_fail (data != NULL);
-
+#if 0
+	g_print ("Adjustment changed to: %g\n", adjustment->value);
+#endif
 	vscrolled_bar = E_VSCROLLED_BAR (data);
 
 	if (!GTK_WIDGET_MAPPED (vscrolled_bar))
@@ -585,19 +605,19 @@ e_vscrolled_bar_adjustment_changed (GtkAdjustment *adjustment,
 
 	/* If the adjustment value is not 0, show the up button. */
 	if (adjustment->value != adjustment->lower) {
-		gtk_widget_map (vscrolled_bar->up_ebox);
-		gdk_window_raise (vscrolled_bar->up_ebox->window);
+		gtk_widget_map (vscrolled_bar->up_button);
+		gdk_window_raise (vscrolled_bar->up_button->window);
 	} else {
-		gtk_widget_unmap (vscrolled_bar->up_ebox);
+		gtk_widget_unmap (vscrolled_bar->up_button);
 	}
 
 	/* If the adjustment value is less than the maximum value, show the
 	   down button. */
 	if (adjustment->value < adjustment->upper - adjustment->page_size) {
-		gtk_widget_map (vscrolled_bar->down_ebox);
-		gdk_window_raise (vscrolled_bar->down_ebox->window);
+		gtk_widget_map (vscrolled_bar->down_button);
+		gdk_window_raise (vscrolled_bar->down_button->window);
 	} else {
-		gtk_widget_unmap (vscrolled_bar->down_ebox);
+		gtk_widget_unmap (vscrolled_bar->down_button);
 	}
 }
 
@@ -677,8 +697,8 @@ e_vscrolled_bar_scroll (gpointer data)
 
 	if (adjustment->value != new_value) {
 		adjustment->value = new_value;
-		g_signal_emit_by_name (adjustment,
-				       "value_changed");
+		gtk_signal_emit_by_name (GTK_OBJECT (adjustment),
+					 "value_changed");
 	}
 
 	return retval;
