@@ -109,7 +109,6 @@ main (int argc, char *argv[])
 
 	gnome_init ("test-shortcut-bar", "0.1", argc, argv);
 
-	gtk_widget_push_visual (gdk_rgb_get_visual ());
 	gtk_widget_push_colormap (gdk_rgb_get_cmap ());
 
 	window = gnome_app_new ("TestShortcutBar", "TestShortCutBar");
@@ -184,17 +183,17 @@ main (int argc, char *argv[])
 			    shortcut_bar);
 
 
-	gtk_widget_pop_visual ();
 	gtk_widget_pop_colormap ();
 
 	/* Load our default icons. */
 	for (i = 0; i < NUM_SHORTCUT_TYPES; i++) {
 		pathname = gnome_pixmap_file (icon_filenames[i]);
 		if (pathname) {
-			icon_pixbufs[i] = gdk_pixbuf_new_from_file (pathname);
+			icon_pixbufs[i] = gdk_pixbuf_new_from_file (pathname, NULL);
 			g_print ("type %d -- %s %s\n",
 				 i, pathname, icon_pixbufs[i] == NULL ? "(not found)" : "");
 		} else {
+			g_warning ("Failed to locate '%s'", icon_filenames [i]);
 			icon_pixbufs[i] = NULL;
 		}
 	}
@@ -449,11 +448,12 @@ show_context_popup (EShortcutBar *shortcut_bar,
 		    gint group_num,
 		    gint item_num)
 {
-	GtkWidget *menu, *menuitem, *label, *pixmap;
+	GtkWidget *menu, *menuitem, *label;
 
 	menu = gtk_menu_new ();
 
-	menuitem = gtk_pixmap_menu_item_new ();
+	menuitem = gtk_image_menu_item_new_from_stock (
+		GNOME_STOCK_MENU_OPEN, NULL);
 	label = gtk_label_new ("Open Folder");
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_widget_show (label);
@@ -461,11 +461,6 @@ show_context_popup (EShortcutBar *shortcut_bar,
 	gtk_widget_set_sensitive (menuitem, FALSE);
 	gtk_widget_show (menuitem);
 	gtk_menu_append (GTK_MENU (menu), menuitem);
-	pixmap = gnome_stock_pixmap_widget (menu, GNOME_STOCK_MENU_OPEN);
-	if (pixmap) {
-		gtk_widget_show(pixmap);
-		gtk_pixmap_menu_item_set_pixmap (GTK_PIXMAP_MENU_ITEM (menuitem), pixmap);
-	}
 
 	menuitem = gtk_menu_item_new_with_label ("Open in New Window");
 	gtk_widget_set_sensitive (menuitem, FALSE);
